!**************************************************************************!
!                          PIP-NN PES for N2OC2H2                          !
!**************************************************************************!

!******************************************************************************
!-->  program to get potential energy for a given geometry after NN
!fitting
!-->  global variables are declared in this module
      module nnparam1
      implicit none
      real*8,parameter::alpha=1.8d0,PI=3.141592653589793238d0
      real*8,parameter::radian=PI/180.0d0,bohr=0.5291772d0
      real*8,parameter::PARA2=27.2114d0
      integer,parameter::nbasis=2390,natom=7,nbond=21
      integer, parameter::ninput1=456
      integer noutput1,nscale1
      integer nhid3,nlayer31,ifunc31,nwe3,nodemax31
      integer,allocatable::nodes3a1(:)
      real*8,allocatable::weight3a1(:,:,:),bias3a1(:,:),&
     &pdel3a1(:),pavg3a1(:)
      end module nnparam1

      subroutine pes(x,igrad,path,p,g,d)

      use nnparam1
      implicit none
      ! number of electronic state
      integer, parameter :: nstates=1
      integer, parameter :: natoms=7
      integer, intent(in) :: igrad
      character(len=1024), intent(in) :: path
      double precision, intent(in) :: x(natoms,3)
      double precision, intent(out) :: p(nstates), g(nstates,natoms,3)
      double precision, intent(out) :: d(nstates,nstates,natoms,3)


      double precision :: v, tx(3,natoms)
      integer :: iatom, idir, j, istate
      !initialize 
      v=0.d0
      g=0.d0
      d=0.d0

      do iatom=1,natoms
        do idir=1,3
          tx(idir, iatom)=x(iatom, idir)
        enddo
      enddo

      if (igrad==0) then
        call pes_init(path)
        call evvdvdx(tx,v)
        deallocate(nodes3a1)
        deallocate(weight3a1)
        deallocate(bias3a1)
        deallocate(pdel3a1)
        deallocate(pavg3a1)
      else
        write (*,*) 'Only energy is available'
      endif

      do istate=1,nstates
        p(istate)=v
      enddo

      endsubroutine



      subroutine evvdvdx(xcart,v)
!**************************************************************************!
!Subroutine to calculate the potential energy
!Xcart     ==>Cartesian coordinates in angstrom
!             H1: xcart(1,1), xcart(2,1), xcart(3,1)
!             H2: xcart(1,2), xcart(2,2), xcart(3,2)
!             C3: xcart(1,3), xcart(2,3), xcart(3,3)
!             C4: xcart(1,4), xcart(2,4), xcart(3,4)
!             N5: xcart(1,5), xcart(2,5), xcart(3,5)
!             N6: xcart(1,6), xcart(2,6), xcart(3,6)
!             N7: xcart(1,7), xcart(2,7), xcart(3,7)
!v         ==>Average potential energy(in eV)
!The total root mean squared error is 16.0 meV
!It's worth nothing that the trajectories should be artificially halted
!when the two forming bond distances C-N and C-O arrived at 1.6 angstrom, 
!otherwise, the product might decompose.
!“Quantitative Dynamics of the N2O + C2H2 → Oxadiazole Reaction: 
!A Model for 1,3-Dipolar Cycloadditions”, 
!Yang Liu, Jun Li*, ACS Omega, 2020, 5, 23343-23350.
!https://pubs.acs.org/doi/10.1021/acsomega.0c03210
!***************************************************************************
      implicit none
      real*8,parameter::alpha=1.8d0,PARA=0.5291772d0
      integer,parameter::natom=7
      integer i,j,k,ndriv
      real*8 v,p(0:2389),r(1:21)
      real*8 xcart(1:3,1:7),m(0:707),xmorse(1:21)
      real*8 x(1:21)
      real*8 txinput(1:456)

      do i=1,natom
       x((3*(i-1)+1):(3*(i-1)+3))=xcart(:,i)
      enddo

      k=0
      do i=1,natom-1
       do j=i+1,natom
        k=k+1
       r(k)=dsqrt(dot_product(xcart(:,i)-xcart(:,j),xcart(:,i)-xcart(:,j)))
        xmorse(k)=dexp(-r(k)/(PARA*alpha))
       enddo
      enddo
      if(k.ne.(natom*(natom-1)/2))stop "error"
      call bemsav(xmorse,p)

      do j=1,456
       txinput(j)=p(j)
      enddo

      call pot3a(txinput,v)

      return
      end subroutine evvdvdx

      subroutine pes_init(path)
      use nnparam1
      implicit none
      character(len=1024), intent(in) :: path
      integer i,ihid,iwe,inode1,inode2,ilay1,ilay2
      integer ibasis,npd,iterm,ib,nfile1,nfile2
      character f1*80
      character(len=1024) :: file_path1, file_path2

      nfile1=4
      nfile2=7

      file_path1 = trim(path)//"/C2H2N2O/weights.txt"
      file_path2 = trim(path)//"/C2H2N2O/biases.txt"

      open(nfile1,file=file_path1,status='old')
      open(nfile2,file=file_path2,status='old')
      read(nfile1,*)nhid3,noutput1
      nscale1=ninput1+noutput1
      nlayer31=nhid3+2 !additional one for input layer and one for output 
      allocate(nodes3a1(nlayer31),pdel3a1(nscale1),pavg3a1(nscale1))
      nodes3a1(1)=ninput1
      nodes3a1(nlayer31)=noutput1
      read(nfile1,*)(nodes3a1(ihid),ihid=2,nhid3+1)
      nodemax31=0
      do i=1,nlayer31
       nodemax31=max(nodemax31,nodes3a1(i))
      enddo
      allocate(weight3a1(nodemax31,nodemax31,2:nlayer31),&
     &bias3a1(nodemax31,2:nlayer31))
      read(nfile1,*)ifunc31,nwe3
      read(nfile1,*)(pdel3a1(i),i=1,nscale1)
      read(nfile1,*)(pavg3a1(i),i=1,nscale1)
      iwe=0
      do ilay1=2,nlayer31
      ilay2=ilay1-1
      do inode1=1,nodes3a1(ilay1)
      do inode2=1,nodes3a1(ilay2) !
      read(nfile1,*)weight3a1(inode2,inode1,ilay1)
      iwe=iwe+1
      enddo
      read(nfile2,*)bias3a1(inode1,ilay1)
      iwe=iwe+1
      enddo
      enddo
      if (iwe.ne.nwe3) then
        write(*,*)'provided number of parameters ',nwe3
        write(*,*)'actual number of parameters ',iwe
        write(*,*)'nwe not equal to iwe, check input files or code'
        stop
      endif

      close(nfile1)
      close(nfile2)

      end subroutine pes_init

!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->
        subroutine pot3a(x,vpot3) ! fhcl,a
        use nnparam1
        implicit none
        integer i,ndriv,inode1,inode2,ilay1,ilay2
        integer j,k,neu1,neu2
        real*8 x(ninput1),y(nodemax31,nlayer31),vpot3
        real*8,allocatable::nxw3(:),nxw2(:,:),nxw1(:,:),ax(:),bx(:)
        real*8 dvdg(ninput1),dvtmp
        real*8, external :: tranfun1

        dvdg=0d0
        dvtmp=0d0          
        do i=1,ninput1
          y(i,1)=(x(i)-pavg3a1(i))/pdel3a1(i)
        enddo

!-->....evaluate the hidden layer
        do ilay1=2,nlayer31-1
         ilay2=ilay1-1
         do inode1=1,nodes3a1(ilay1)
          y(inode1,ilay1)=bias3a1(inode1,ilay1)
          do inode2=1,nodes3a1(ilay2)
           y(inode1,ilay1)=y(inode1,ilay1)+&
     &y(inode2,ilay2)*weight3a1(inode2,inode1,ilay1)
          enddo
          y(inode1,ilay1)=tranfun1(y(inode1,ilay1),ifunc31)
         enddo
        enddo

!-->....now evaluate the output
        ilay1=nlayer31
        ilay2=ilay1-1
        do inode1=1,nodes3a1(ilay1)
        y(inode1,ilay1)=bias3a1(inode1,ilay1)
        do inode2=1,nodes3a1(ilay2)
        y(inode1,ilay1)=y(inode1,ilay1)+&
     &y(inode2,ilay2)*weight3a1(inode2,inode1,ilay1)
        enddo
        enddo

!-->....the value of output layer is the fitted potntial 
        vpot3=y(nodes3a1(nlayer31),nlayer31)*pdel3a1(nscale1)+&
     &  pavg3a1(nscale1)

!        write(*,'(f16.8)')vpot3
!        stop
        return
        end subroutine pot3a
!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->!-->

        function tranfun1(x,ifunc)
        implicit none
        integer ifunc
        real*8 tranfun1,x
!    ifunc=1, transfer function is hyperbolic tangent function, 'tansig'
!    ifunc=2, transfer function is log sigmoid function, 'logsig'
!    ifunc=3, transfer function is pure linear function, 'purelin'. It is imposed to the output layer by default
        if (ifunc.eq.1) then
        tranfun1=dtanh(x)
        else if (ifunc.eq.2) then
        tranfun1=1d0/(1d0+dexp(-x))
        else if (ifunc.eq.3) then
        tranfun1=x
        endif
        return
        end function tranfun1

        FUNCTION LOGSIG1(X)
        REAL*8 X,LOGSIG1
        LOGSIG1=1.d0/(1.d0+DEXP(-X))
        RETURN
        END FUNCTION LOGSIG1

!********************************************************
      subroutine bemsav(x,p)
      implicit none
      real*8 x(1:21)
      real*8 p(0:2389)
      real*8 m(0:707)
      
      call evmono(x,m)
      call evpoly(m,p)
      
      return
      end subroutine bemsav
  
      subroutine evmono(x,m)
      implicit none
      real*8 x(1:21)
      real*8 m(0:707)

      
      m(0) = 1.0D0
      m(1) = x(21)
      m(2) = x(20)
      m(3) = x(19)
      m(4) = x(18)
      m(5) = x(15)
      m(6) = x(17)
      m(7) = x(16)
      m(8) = x(14)
      m(9) = x(13)
      m(10) = x(12)
      m(11) = x(11)
      m(12) = x(6)
      m(13) = x(10)
      m(14) = x(9)
      m(15) = x(5)
      m(16) = x(4)
      m(17) = x(8)
      m(18) = x(7)
      m(19) = x(3)
      m(20) = x(2)
      m(21) = x(1)
      m(22) = m(1)*m(2)
      m(23) = m(4)*m(5)
      m(24) = m(2)*m(6)
      m(25) = m(1)*m(7)
      m(26) = m(2)*m(8)
      m(27) = m(1)*m(9)
      m(28) = m(5)*m(6)
      m(29) = m(5)*m(7)
      m(30) = m(4)*m(8)
      m(31) = m(4)*m(9)
      m(32) = m(7)*m(8)
      m(33) = m(6)*m(9)
      m(34) = m(6)*m(8)
      m(35) = m(7)*m(9)
      m(36) = m(6)*m(7)
      m(37) = m(8)*m(9)
      m(38) = m(11)*m(12)
      m(39) = m(2)*m(13)
      m(40) = m(1)*m(14)
      m(41) = m(2)*m(15)
      m(42) = m(1)*m(16)
      m(43) = m(7)*m(13)
      m(44) = m(9)*m(13)
      m(45) = m(6)*m(14)
      m(46) = m(8)*m(14)
      m(47) = m(7)*m(15)
      m(48) = m(9)*m(15)
      m(49) = m(6)*m(16)
      m(50) = m(8)*m(16)
      m(51) = m(12)*m(13)
      m(52) = m(12)*m(14)
      m(53) = m(11)*m(15)
      m(54) = m(11)*m(16)
      m(55) = m(14)*m(15)
      m(56) = m(13)*m(16)
      m(57) = m(13)*m(15)
      m(58) = m(14)*m(16)
      m(59) = m(13)*m(14)
      m(60) = m(15)*m(16)
      m(61) = m(5)*m(17)
      m(62) = m(4)*m(18)
      m(63) = m(5)*m(19)
      m(64) = m(4)*m(20)
      m(65) = m(8)*m(17)
      m(66) = m(9)*m(17)
      m(67) = m(6)*m(18)
      m(68) = m(7)*m(18)
      m(69) = m(8)*m(19)
      m(70) = m(9)*m(19)
      m(71) = m(6)*m(20)
      m(72) = m(7)*m(20)
      m(73) = m(12)*m(17)
      m(74) = m(12)*m(18)
      m(75) = m(11)*m(19)
      m(76) = m(11)*m(20)
      m(77) = m(15)*m(17)
      m(78) = m(15)*m(18)
      m(79) = m(16)*m(17)
      m(80) = m(16)*m(18)
      m(81) = m(13)*m(19)
      m(82) = m(14)*m(19)
      m(83) = m(13)*m(20)
      m(84) = m(14)*m(20)
      m(85) = m(18)*m(19)
      m(86) = m(17)*m(20)
      m(87) = m(17)*m(19)
      m(88) = m(18)*m(20)
      m(89) = m(17)*m(18)
      m(90) = m(19)*m(20)
      m(91) = m(2)*m(28)
      m(92) = m(1)*m(29)
      m(93) = m(2)*m(30)
      m(94) = m(1)*m(31)
      m(95) = m(2)*m(34)
      m(96) = m(1)*m(35)
      m(97) = m(5)*m(36)
      m(98) = m(4)*m(37)
      m(99) = m(6)*m(32)
      m(100) = m(6)*m(35)
      m(101) = m(6)*m(37)
      m(102) = m(7)*m(37)
      m(103) = m(2)*m(43)
      m(104) = m(2)*m(44)
      m(105) = m(1)*m(45)
      m(106) = m(1)*m(46)
      m(107) = m(2)*m(47)
      m(108) = m(2)*m(48)
      m(109) = m(1)*m(49)
      m(110) = m(1)*m(50)
      m(111) = m(5)*m(43)
      m(112) = m(4)*m(44)
      m(113) = m(5)*m(45)
      m(114) = m(4)*m(46)
      m(115) = m(5)*m(47)
      m(116) = m(4)*m(48)
      m(117) = m(5)*m(49)
      m(118) = m(4)*m(50)
      m(119) = m(7)*m(44)
      m(120) = m(6)*m(46)
      m(121) = m(7)*m(48)
      m(122) = m(6)*m(50)
      m(123) = m(2)*m(51)
      m(124) = m(1)*m(52)
      m(125) = m(2)*m(53)
      m(126) = m(1)*m(54)
      m(127) = m(7)*m(51)
      m(128) = m(9)*m(51)
      m(129) = m(6)*m(52)
      m(130) = m(8)*m(52)
      m(131) = m(7)*m(53)
      m(132) = m(9)*m(53)
      m(133) = m(6)*m(54)
      m(134) = m(8)*m(54)
      m(135) = m(2)*m(57)
      m(136) = m(1)*m(58)
      m(137) = m(7)*m(57)
      m(138) = m(9)*m(57)
      m(139) = m(6)*m(58)
      m(140) = m(8)*m(58)
      m(141) = m(12)*m(59)
      m(142) = m(11)*m(60)
      m(143) = m(13)*m(55)
      m(144) = m(13)*m(58)
      m(145) = m(13)*m(60)
      m(146) = m(14)*m(60)
      m(147) = m(2)*m(65)
      m(148) = m(1)*m(66)
      m(149) = m(2)*m(67)
      m(150) = m(1)*m(68)
      m(151) = m(2)*m(69)
      m(152) = m(1)*m(70)
      m(153) = m(2)*m(71)
      m(154) = m(1)*m(72)
      m(155) = m(5)*m(65)
      m(156) = m(5)*m(66)
      m(157) = m(4)*m(67)
      m(158) = m(4)*m(68)
      m(159) = m(5)*m(69)
      m(160) = m(5)*m(70)
      m(161) = m(4)*m(71)
      m(162) = m(4)*m(72)
      m(163) = m(8)*m(66)
      m(164) = m(6)*m(68)
      m(165) = m(8)*m(70)
      m(166) = m(6)*m(72)
      m(167) = m(5)*m(73)
      m(168) = m(4)*m(74)
      m(169) = m(5)*m(75)
      m(170) = m(4)*m(76)
      m(171) = m(8)*m(73)
      m(172) = m(9)*m(73)
      m(173) = m(6)*m(74)
      m(174) = m(7)*m(74)
      m(175) = m(8)*m(75)
      m(176) = m(9)*m(75)
      m(177) = m(6)*m(76)
      m(178) = m(7)*m(76)
      m(179) = m(2)*m(77)
      m(180) = m(2)*m(78)
      m(181) = m(1)*m(79)
      m(182) = m(1)*m(80)
      m(183) = m(2)*m(81)
      m(184) = m(1)*m(82)
      m(185) = m(2)*m(83)
      m(186) = m(1)*m(84)
      m(187) = m(5)*m(77)
      m(188) = m(4)*m(78)
      m(189) = m(5)*m(79)
      m(190) = m(4)*m(80)
      m(191) = m(5)*m(81)
      m(192) = m(5)*m(82)
      m(193) = m(4)*m(83)
      m(194) = m(4)*m(84)
      m(195) = m(9)*m(77)
      m(196) = m(7)*m(78)
      m(197) = m(8)*m(79)
      m(198) = m(6)*m(80)
      m(199) = m(9)*m(81)
      m(200) = m(8)*m(82)
      m(201) = m(7)*m(83)
      m(202) = m(6)*m(84)
      m(203) = m(8)*m(77)
      m(204) = m(6)*m(78)
      m(205) = m(9)*m(79)
      m(206) = m(7)*m(80)
      m(207) = m(8)*m(81)
      m(208) = m(9)*m(82)
      m(209) = m(6)*m(83)
      m(210) = m(7)*m(84)
      m(211) = m(7)*m(77)
      m(212) = m(9)*m(78)
      m(213) = m(6)*m(79)
      m(214) = m(8)*m(80)
      m(215) = m(7)*m(81)
      m(216) = m(6)*m(82)
      m(217) = m(9)*m(83)
      m(218) = m(8)*m(84)
      m(219) = m(12)*m(77)
      m(220) = m(12)*m(78)
      m(221) = m(12)*m(79)
      m(222) = m(12)*m(80)
      m(223) = m(11)*m(81)
      m(224) = m(11)*m(82)
      m(225) = m(11)*m(83)
      m(226) = m(11)*m(84)
      m(227) = m(15)*m(79)
      m(228) = m(15)*m(80)
      m(229) = m(13)*m(82)
      m(230) = m(13)*m(84)
      m(231) = m(5)*m(87)
      m(232) = m(4)*m(88)
      m(233) = m(8)*m(87)
      m(234) = m(9)*m(87)
      m(235) = m(6)*m(88)
      m(236) = m(7)*m(88)
      m(237) = m(13)*m(66)
      m(238) = m(14)*m(65)
      m(239) = m(13)*m(68)
      m(240) = m(14)*m(67)
      m(241) = m(15)*m(70)
      m(242) = m(16)*m(69)
      m(243) = m(15)*m(72)
      m(244) = m(16)*m(71)
      m(245) = m(12)*m(89)
      m(246) = m(11)*m(90)
      m(247) = m(15)*m(89)
      m(248) = m(16)*m(89)
      m(249) = m(13)*m(90)
      m(250) = m(14)*m(90)
      m(251) = m(17)*m(85)
      m(252) = m(17)*m(88)
      m(253) = m(17)*m(90)
      m(254) = m(18)*m(90)
      m(255) = m(25)*m(30)
      m(256) = m(26)*m(29)
      m(257) = m(24)*m(31)
      m(258) = m(27)*m(28)
      m(259) = m(2)*m(99)
      m(260) = m(1)*m(100)
      m(261) = m(2)*m(101)
      m(262) = m(1)*m(102)
      m(263) = m(5)*m(99)
      m(264) = m(5)*m(100)
      m(265) = m(4)*m(101)
      m(266) = m(4)*m(102)
      m(267) = m(6)*m(102)
      m(268) = m(2)*m(111)
      m(269) = m(2)*m(112)
      m(270) = m(1)*m(113)
      m(271) = m(1)*m(114)
      m(272) = m(2)*m(115)
      m(273) = m(2)*m(116)
      m(274) = m(1)*m(117)
      m(275) = m(1)*m(118)
      m(276) = m(2)*m(119)
      m(277) = m(1)*m(120)
      m(278) = m(2)*m(121)
      m(279) = m(1)*m(122)
      m(280) = m(30)*m(43)
      m(281) = m(28)*m(44)
      m(282) = m(29)*m(46)
      m(283) = m(31)*m(45)
      m(284) = m(30)*m(47)
      m(285) = m(28)*m(48)
      m(286) = m(29)*m(50)
      m(287) = m(31)*m(49)
      m(288) = m(6)*m(119)
      m(289) = m(8)*m(119)
      m(290) = m(7)*m(120)
      m(291) = m(9)*m(120)
      m(292) = m(6)*m(121)
      m(293) = m(8)*m(121)
      m(294) = m(7)*m(122)
      m(295) = m(9)*m(122)
      m(296) = m(2)*m(127)
      m(297) = m(2)*m(128)
      m(298) = m(1)*m(129)
      m(299) = m(1)*m(130)
      m(300) = m(2)*m(131)
      m(301) = m(2)*m(132)
      m(302) = m(1)*m(133)
      m(303) = m(1)*m(134)
      m(304) = m(5)*m(127)
      m(305) = m(4)*m(128)
      m(306) = m(5)*m(129)
      m(307) = m(4)*m(130)
      m(308) = m(5)*m(131)
      m(309) = m(4)*m(132)
      m(310) = m(5)*m(133)
      m(311) = m(4)*m(134)
      m(312) = m(7)*m(128)
      m(313) = m(6)*m(130)
      m(314) = m(7)*m(132)
      m(315) = m(6)*m(134)
      m(316) = m(2)*m(137)
      m(317) = m(2)*m(138)
      m(318) = m(1)*m(139)
      m(319) = m(1)*m(140)
      m(320) = m(5)*m(137)
      m(321) = m(4)*m(138)
      m(322) = m(5)*m(139)
      m(323) = m(4)*m(140)
      m(324) = m(7)*m(138)
      m(325) = m(6)*m(140)
      m(326) = m(40)*m(53)
      m(327) = m(41)*m(52)
      m(328) = m(39)*m(54)
      m(329) = m(42)*m(51)
      m(330) = m(45)*m(53)
      m(331) = m(46)*m(53)
      m(332) = m(47)*m(52)
      m(333) = m(48)*m(52)
      m(334) = m(43)*m(54)
      m(335) = m(44)*m(54)
      m(336) = m(49)*m(51)
      m(337) = m(50)*m(51)
      m(338) = m(2)*m(143)
      m(339) = m(1)*m(144)
      m(340) = m(2)*m(145)
      m(341) = m(1)*m(146)
      m(342) = m(7)*m(143)
      m(343) = m(9)*m(143)
      m(344) = m(6)*m(144)
      m(345) = m(8)*m(144)
      m(346) = m(7)*m(145)
      m(347) = m(9)*m(145)
      m(348) = m(6)*m(146)
      m(349) = m(8)*m(146)
      m(350) = m(12)*m(143)
      m(351) = m(12)*m(144)
      m(352) = m(11)*m(145)
      m(353) = m(11)*m(146)
      m(354) = m(13)*m(146)
      m(355) = m(2)*m(155)
      m(356) = m(1)*m(156)
      m(357) = m(2)*m(157)
      m(358) = m(1)*m(158)
      m(359) = m(2)*m(159)
      m(360) = m(1)*m(160)
      m(361) = m(2)*m(161)
      m(362) = m(1)*m(162)
      m(363) = m(5)*m(163)
      m(364) = m(4)*m(164)
      m(365) = m(5)*m(165)
      m(366) = m(4)*m(166)
      m(367) = m(25)*m(65)
      m(368) = m(24)*m(66)
      m(369) = m(26)*m(68)
      m(370) = m(27)*m(67)
      m(371) = m(25)*m(69)
      m(372) = m(24)*m(70)
      m(373) = m(26)*m(72)
      m(374) = m(27)*m(71)
      m(375) = m(6)*m(163)
      m(376) = m(7)*m(163)
      m(377) = m(8)*m(164)
      m(378) = m(9)*m(164)
      m(379) = m(6)*m(165)
      m(380) = m(7)*m(165)
      m(381) = m(8)*m(166)
      m(382) = m(9)*m(166)
      m(383) = m(2)*m(171)
      m(384) = m(1)*m(172)
      m(385) = m(2)*m(173)
      m(386) = m(1)*m(174)
      m(387) = m(2)*m(175)
      m(388) = m(1)*m(176)
      m(389) = m(2)*m(177)
      m(390) = m(1)*m(178)
      m(391) = m(5)*m(171)
      m(392) = m(5)*m(172)
      m(393) = m(4)*m(173)
      m(394) = m(4)*m(174)
      m(395) = m(5)*m(175)
      m(396) = m(5)*m(176)
      m(397) = m(4)*m(177)
      m(398) = m(4)*m(178)
      m(399) = m(8)*m(172)
      m(400) = m(6)*m(174)
      m(401) = m(8)*m(176)
      m(402) = m(6)*m(178)
      m(403) = m(2)*m(187)
      m(404) = m(2)*m(188)
      m(405) = m(1)*m(189)
      m(406) = m(1)*m(190)
      m(407) = m(2)*m(191)
      m(408) = m(1)*m(192)
      m(409) = m(2)*m(193)
      m(410) = m(1)*m(194)
      m(411) = m(2)*m(195)
      m(412) = m(2)*m(196)
      m(413) = m(1)*m(197)
      m(414) = m(1)*m(198)
      m(415) = m(2)*m(199)
      m(416) = m(1)*m(200)
      m(417) = m(2)*m(201)
      m(418) = m(1)*m(202)
      m(419) = m(5)*m(195)
      m(420) = m(4)*m(196)
      m(421) = m(5)*m(197)
      m(422) = m(4)*m(198)
      m(423) = m(5)*m(199)
      m(424) = m(5)*m(200)
      m(425) = m(4)*m(201)
      m(426) = m(4)*m(202)
      m(427) = m(2)*m(203)
      m(428) = m(2)*m(204)
      m(429) = m(1)*m(205)
      m(430) = m(1)*m(206)
      m(431) = m(2)*m(207)
      m(432) = m(1)*m(208)
      m(433) = m(2)*m(209)
      m(434) = m(1)*m(210)
      m(435) = m(5)*m(203)
      m(436) = m(4)*m(204)
      m(437) = m(5)*m(205)
      m(438) = m(4)*m(206)
      m(439) = m(5)*m(207)
      m(440) = m(5)*m(208)
      m(441) = m(4)*m(209)
      m(442) = m(4)*m(210)
      m(443) = m(8)*m(195)
      m(444) = m(6)*m(196)
      m(445) = m(8)*m(205)
      m(446) = m(6)*m(206)
      m(447) = m(8)*m(199)
      m(448) = m(8)*m(208)
      m(449) = m(6)*m(201)
      m(450) = m(6)*m(210)
      m(451) = m(2)*m(211)
      m(452) = m(2)*m(212)
      m(453) = m(1)*m(213)
      m(454) = m(1)*m(214)
      m(455) = m(2)*m(215)
      m(456) = m(1)*m(216)
      m(457) = m(2)*m(217)
      m(458) = m(1)*m(218)
      m(459) = m(5)*m(211)
      m(460) = m(4)*m(212)
      m(461) = m(5)*m(213)
      m(462) = m(4)*m(214)
      m(463) = m(5)*m(215)
      m(464) = m(5)*m(216)
      m(465) = m(4)*m(217)
      m(466) = m(4)*m(218)
      m(467) = m(7)*m(195)
      m(468) = m(7)*m(212)
      m(469) = m(6)*m(197)
      m(470) = m(6)*m(214)
      m(471) = m(7)*m(199)
      m(472) = m(6)*m(200)
      m(473) = m(7)*m(217)
      m(474) = m(6)*m(218)
      m(475) = m(7)*m(203)
      m(476) = m(6)*m(212)
      m(477) = m(6)*m(205)
      m(478) = m(7)*m(214)
      m(479) = m(7)*m(207)
      m(480) = m(6)*m(208)
      m(481) = m(6)*m(217)
      m(482) = m(7)*m(218)
      m(483) = m(2)*m(219)
      m(484) = m(2)*m(220)
      m(485) = m(1)*m(221)
      m(486) = m(1)*m(222)
      m(487) = m(2)*m(223)
      m(488) = m(1)*m(224)
      m(489) = m(2)*m(225)
      m(490) = m(1)*m(226)
      m(491) = m(5)*m(219)
      m(492) = m(4)*m(220)
      m(493) = m(5)*m(221)
      m(494) = m(4)*m(222)
      m(495) = m(5)*m(223)
      m(496) = m(5)*m(224)
      m(497) = m(4)*m(225)
      m(498) = m(4)*m(226)
      m(499) = m(9)*m(219)
      m(500) = m(7)*m(220)
      m(501) = m(8)*m(221)
      m(502) = m(6)*m(222)
      m(503) = m(9)*m(223)
      m(504) = m(8)*m(224)
      m(505) = m(7)*m(225)
      m(506) = m(6)*m(226)
      m(507) = m(8)*m(219)
      m(508) = m(6)*m(220)
      m(509) = m(9)*m(221)
      m(510) = m(7)*m(222)
      m(511) = m(8)*m(223)
      m(512) = m(9)*m(224)
      m(513) = m(6)*m(225)
      m(514) = m(7)*m(226)
      m(515) = m(7)*m(219)
      m(516) = m(9)*m(220)
      m(517) = m(6)*m(221)
      m(518) = m(8)*m(222)
      m(519) = m(7)*m(223)
      m(520) = m(6)*m(224)
      m(521) = m(9)*m(225)
      m(522) = m(8)*m(226)
      m(523) = m(5)*m(227)
      m(524) = m(4)*m(228)
      m(525) = m(5)*m(229)
      m(526) = m(4)*m(230)
      m(527) = m(8)*m(227)
      m(528) = m(9)*m(227)
      m(529) = m(6)*m(228)
      m(530) = m(7)*m(228)
      m(531) = m(8)*m(229)
      m(532) = m(9)*m(229)
      m(533) = m(6)*m(230)
      m(534) = m(7)*m(230)
      m(535) = m(12)*m(227)
      m(536) = m(12)*m(228)
      m(537) = m(11)*m(229)
      m(538) = m(11)*m(230)
      m(539) = m(2)*m(233)
      m(540) = m(1)*m(234)
      m(541) = m(2)*m(235)
      m(542) = m(1)*m(236)
      m(543) = m(5)*m(233)
      m(544) = m(5)*m(234)
      m(545) = m(4)*m(235)
      m(546) = m(4)*m(236)
      m(547) = m(8)*m(234)
      m(548) = m(6)*m(236)
      m(549) = m(62)*m(75)
      m(550) = m(63)*m(74)
      m(551) = m(61)*m(76)
      m(552) = m(64)*m(73)
      m(553) = m(67)*m(75)
      m(554) = m(68)*m(75)
      m(555) = m(69)*m(74)
      m(556) = m(70)*m(74)
      m(557) = m(65)*m(76)
      m(558) = m(66)*m(76)
      m(559) = m(71)*m(73)
      m(560) = m(72)*m(73)
      m(561) = m(2)*m(237)
      m(562) = m(1)*m(238)
      m(563) = m(2)*m(239)
      m(564) = m(1)*m(240)
      m(565) = m(2)*m(241)
      m(566) = m(1)*m(242)
      m(567) = m(2)*m(243)
      m(568) = m(1)*m(244)
      m(569) = m(5)*m(237)
      m(570) = m(5)*m(238)
      m(571) = m(4)*m(239)
      m(572) = m(4)*m(240)
      m(573) = m(5)*m(241)
      m(574) = m(5)*m(242)
      m(575) = m(4)*m(243)
      m(576) = m(4)*m(244)
      m(577) = m(43)*m(65)
      m(578) = m(45)*m(66)
      m(579) = m(44)*m(67)
      m(580) = m(46)*m(68)
      m(581) = m(47)*m(69)
      m(582) = m(49)*m(70)
      m(583) = m(48)*m(71)
      m(584) = m(50)*m(72)
      m(585) = m(12)*m(237)
      m(586) = m(12)*m(238)
      m(587) = m(12)*m(239)
      m(588) = m(12)*m(240)
      m(589) = m(11)*m(241)
      m(590) = m(11)*m(242)
      m(591) = m(11)*m(243)
      m(592) = m(11)*m(244)
      m(593) = m(40)*m(77)
      m(594) = m(40)*m(78)
      m(595) = m(39)*m(79)
      m(596) = m(39)*m(80)
      m(597) = m(41)*m(82)
      m(598) = m(42)*m(81)
      m(599) = m(41)*m(84)
      m(600) = m(42)*m(83)
      m(601) = m(14)*m(203)
      m(602) = m(14)*m(204)
      m(603) = m(13)*m(205)
      m(604) = m(13)*m(206)
      m(605) = m(14)*m(241)
      m(606) = m(13)*m(242)
      m(607) = m(14)*m(243)
      m(608) = m(13)*m(244)
      m(609) = m(45)*m(77)
      m(610) = m(46)*m(78)
      m(611) = m(43)*m(79)
      m(612) = m(44)*m(80)
      m(613) = m(47)*m(82)
      m(614) = m(49)*m(81)
      m(615) = m(48)*m(84)
      m(616) = m(50)*m(83)
      m(617) = m(13)*m(195)
      m(618) = m(13)*m(196)
      m(619) = m(14)*m(197)
      m(620) = m(14)*m(198)
      m(621) = m(13)*m(241)
      m(622) = m(14)*m(242)
      m(623) = m(13)*m(243)
      m(624) = m(14)*m(244)
      m(625) = m(13)*m(227)
      m(626) = m(14)*m(227)
      m(627) = m(13)*m(228)
      m(628) = m(14)*m(228)
      m(629) = m(15)*m(229)
      m(630) = m(16)*m(229)
      m(631) = m(15)*m(230)
      m(632) = m(16)*m(230)
      m(633) = m(62)*m(81)
      m(634) = m(62)*m(82)
      m(635) = m(63)*m(78)
      m(636) = m(63)*m(80)
      m(637) = m(61)*m(83)
      m(638) = m(61)*m(84)
      m(639) = m(64)*m(77)
      m(640) = m(64)*m(79)
      m(641) = m(18)*m(215)
      m(642) = m(18)*m(216)
      m(643) = m(18)*m(241)
      m(644) = m(18)*m(242)
      m(645) = m(17)*m(217)
      m(646) = m(17)*m(218)
      m(647) = m(17)*m(243)
      m(648) = m(17)*m(244)
      m(649) = m(67)*m(81)
      m(650) = m(68)*m(82)
      m(651) = m(69)*m(78)
      m(652) = m(70)*m(80)
      m(653) = m(65)*m(83)
      m(654) = m(66)*m(84)
      m(655) = m(71)*m(77)
      m(656) = m(72)*m(79)
      m(657) = m(13)*m(234)
      m(658) = m(14)*m(233)
      m(659) = m(15)*m(234)
      m(660) = m(16)*m(233)
      m(661) = m(13)*m(236)
      m(662) = m(14)*m(235)
      m(663) = m(15)*m(236)
      m(664) = m(16)*m(235)
      m(665) = m(2)*m(247)
      m(666) = m(1)*m(248)
      m(667) = m(2)*m(249)
      m(668) = m(1)*m(250)
      m(669) = m(7)*m(247)
      m(670) = m(9)*m(247)
      m(671) = m(6)*m(248)
      m(672) = m(8)*m(248)
      m(673) = m(7)*m(249)
      m(674) = m(9)*m(249)
      m(675) = m(6)*m(250)
      m(676) = m(8)*m(250)
      m(677) = m(12)*m(247)
      m(678) = m(12)*m(248)
      m(679) = m(11)*m(249)
      m(680) = m(11)*m(250)
      m(681) = m(15)*m(248)
      m(682) = m(13)*m(250)
      m(683) = m(5)*m(251)
      m(684) = m(4)*m(252)
      m(685) = m(5)*m(253)
      m(686) = m(4)*m(254)
      m(687) = m(8)*m(251)
      m(688) = m(9)*m(251)
      m(689) = m(6)*m(252)
      m(690) = m(7)*m(252)
      m(691) = m(8)*m(253)
      m(692) = m(9)*m(253)
      m(693) = m(6)*m(254)
      m(694) = m(7)*m(254)
      m(695) = m(12)*m(251)
      m(696) = m(12)*m(252)
      m(697) = m(11)*m(253)
      m(698) = m(11)*m(254)
      m(699) = m(15)*m(251)
      m(700) = m(16)*m(251)
      m(701) = m(15)*m(252)
      m(702) = m(16)*m(252)
      m(703) = m(13)*m(253)
      m(704) = m(14)*m(253)
      m(705) = m(13)*m(254)
      m(706) = m(14)*m(254)
      m(707) = m(17)*m(254)

      return
      end subroutine evmono

      subroutine evpoly(m,p)
      implicit none
      real*8 p(0:2389)
      real*8 m(0:707)
      
      p(0) = m(0)
      p(1) = m(1) + m(2)
      p(2) = m(3)
      p(3) = m(4) + m(5)
      p(4) = m(6) + m(7) + m(8) + m(9)
      p(5) = m(10)
      p(6) = m(11) + m(12)
      p(7) = m(13) + m(14) + m(15) + m(16)
      p(8) = m(17) + m(18) + m(19) + m(20)
      p(9) = m(21)
      p(10) = m(22)
      p(11) = p(2)*p(1)
      p(12) = p(1)*p(3)
      p(13) = p(2)*p(3)
      p(14) = m(23)
      p(15) = m(24) + m(25) + m(26) + m(27)
      p(16) = p(1)*p(4) - p(15)
      p(17) = p(2)*p(4)
      p(18) = m(28) + m(29) + m(30) + m(31)
      p(19) = m(32) + m(33)
      p(20) = m(34) + m(35)
      p(21) = p(3)*p(4) - p(18)
      p(22) = m(36) + m(37)
      p(23) = p(5)*p(1)
      p(24) = p(2)*p(5)
      p(25) = p(5)*p(3)
      p(26) = p(5)*p(4)
      p(27) = p(1)*p(6)
      p(28) = p(2)*p(6)
      p(29) = p(3)*p(6)
      p(30) = p(4)*p(6)
      p(31) = p(5)*p(6)
      p(32) = m(38)
      p(33) = m(39) + m(40) + m(41) + m(42)
      p(34) = p(1)*p(7) - p(33)
      p(35) = p(2)*p(7)
      p(36) = p(3)*p(7)
      p(37) = m(43)+m(44)+m(45)+m(46)+m(47)+m(48)+ m(49) + m(50)
      p(38) = p(4)*p(7) - p(37)
      p(39) = p(5)*p(7)
      p(40) = m(51) + m(52) + m(53) + m(54)
      p(41) = m(55) + m(56)
      p(42) = m(57) + m(58)
      p(43) = p(6)*p(7) - p(40)
      p(44) = m(59) + m(60)
      p(45) = p(1)*p(8)
      p(46) = p(2)*p(8)
      p(47) = m(61) + m(62) + m(63) + m(64)
      p(48) = m(65) + m(66) + m(67) + m(68) + m(69)+m(70)+m(71)+m(72)
      p(49) = p(3)*p(8) - p(47)
      p(50) = p(4)*p(8) - p(48)
      p(51) = p(5)*p(8)
      p(52) = m(73) + m(74) + m(75) + m(76)
      p(53) = m(77) + m(78) + m(79) + m(80) +m(81)+m(82)+m(83)+m(84)
      p(54) = m(85) + m(86)
      p(55) = m(87) + m(88)
      p(56) = p(6)*p(8) - p(52)
      p(57) = p(7)*p(8) - p(53)
      p(58) = m(89) + m(90)
      p(59) = p(9)*p(1)
      p(60) = p(2)*p(9)
      p(61) = p(9)*p(3)
      p(62) = p(9)*p(4)
      p(63) = p(5)*p(9)
      p(64) = p(9)*p(6)
      p(65) = p(9)*p(7)
      p(66) = p(9)*p(8)
      p(67) = p(1)*p(1) - p(10) - p(10)
      p(68) = p(2)*p(2)
      p(69) = p(3)*p(3) - p(14) - p(14)
      p(70) = p(4)*p(4)-p(22)-p(20)-p(19) - p(22) - p(20) - p(19)
      p(71) = p(5)*p(5)
      p(72) = p(6)*p(6) - p(32) - p(32)
      p(73) = p(7)*p(7) - p(44) - p(42)-p(41)-p(44)-p(42)-p(41)
      p(74) = p(8)*p(8) - p(58) - p(55)-p(54)-p(58)-p(55)-p(54)
      p(75) = p(9)*p(9)
      p(76) = p(2)*p(10)
      p(77) = p(10)*p(3)
      p(78) = p(2)*p(12)
      p(79) = p(14)*p(1)
      p(80) = p(2)*p(14)
      p(81) = p(10)*p(4)
      p(82) = p(2)*p(15)
      p(83) = p(2)*p(16)
      p(84) = m(91) + m(92) + m(93) + m(94)
      p(85) = p(1)*p(18) - p(84)
      p(86) = p(2)*p(18)
      p(87) = p(1)*p(19)
      p(88) = p(2)*p(19)
      p(89) = m(95) + m(96)
      p(90) = p(1)*p(20) - p(89)
      p(91) = p(2)*p(20)
      p(92) = p(3)*p(15) - p(84)
      p(93) = p(1)*p(21) - p(92)
      p(94) = p(2)*p(21)
      p(95) = p(14)*p(4)
      p(96) = p(3)*p(19)
      p(97) = p(3)*p(20)
      p(98) = p(1)*p(22)
      p(99) = p(2)*p(22)
      p(100) = m(97) + m(98)
      p(101) = m(99) + m(100) + m(101) + m(102)
      p(102) = p(3)*p(22) - p(100)
      p(103) = p(5)*p(10)
      p(104) = p(2)*p(23)
      p(105) = p(5)*p(12)
      p(106) = p(2)*p(25)
      p(107) = p(5)*p(14)
      p(108) = p(5)*p(15)
      p(109) = p(5)*p(16)
      p(110) = p(2)*p(26)
      p(111) = p(5)*p(18)
      p(112) = p(5)*p(19)
      p(113) = p(5)*p(20)
      p(114) = p(5)*p(21)
      p(115) = p(5)*p(22)
      p(116) = p(10)*p(6)
      p(117) = p(2)*p(27)
      p(118) = p(1)*p(29)
      p(119) = p(2)*p(29)
      p(120) = p(14)*p(6)
      p(121) = p(6)*p(15)
      p(122) = p(6)*p(16)
      p(123) = p(2)*p(30)
      p(124) = p(6)*p(18)
      p(125) = p(6)*p(19)
      p(126) = p(6)*p(20)
      p(127) = p(6)*p(21)
      p(128) = p(6)*p(22)
      p(129) = p(5)*p(27)
      p(130) = p(2)*p(31)
      p(131) = p(5)*p(29)
      p(132) = p(5)*p(30)
      p(133) = p(32)*p(1)
      p(134) = p(2)*p(32)
      p(135) = p(32)*p(3)
      p(136) = p(32)*p(4)
      p(137) = p(5)*p(32)
      p(138) = p(10)*p(7)
      p(139) = p(2)*p(33)
      p(140) = p(2)*p(34)
      p(141) = p(3)*p(33)
      p(142) = p(3)*p(34)
      p(143) = p(2)*p(36)
      p(144) = p(14)*p(7)
      p(145) = m(103)+m(104)+m(105)+m(106)+m(107)+m(108)+m(109)+m(110)
      p(146) = p(1)*p(37) - p(145)
      p(147) = p(2)*p(37)
      p(148) = m(111) + m(112) + m(113) + m(114) + m(115) + m(116)&
     &       + m(117) + m(118)
      p(149) = m(119) + m(120) + m(121) + m(122)
      p(150) = p(3)*p(37) - p(148)
      p(151) = p(4)*p(33) - p(145)
      p(152) = p(1)*p(38) - p(151)
      p(153) = p(2)*p(38)
      p(154) = p(7)*p(18) - p(148)
      p(155) = p(7)*p(19)
      p(156) = p(7)*p(20) - p(149)
      p(157) = p(3)*p(38) - p(154)
      p(158) = p(7)*p(22)
      p(159) = p(5)*p(33)
      p(160) = p(5)*p(34)
      p(161) = p(2)*p(39)
      p(162) = p(5)*p(36)
      p(163) = p(5)*p(37)
      p(164) = p(5)*p(38)
      p(165) = m(123) + m(124) + m(125) + m(126)
      p(166) = p(1)*p(40) - p(165)
      p(167) = p(2)*p(40)
      p(168) = p(3)*p(40)
      p(169) = m(127) + m(128) + m(129) + m(130) + m(131) + m(132)&
     &       + m(133) + m(134)
      p(170) = p(4)*p(40) - p(169)
      p(171) = p(5)*p(40)
      p(172) = p(1)*p(41)
      p(173) = p(2)*p(41)
      p(174) = p(3)*p(41)
      p(175) = p(4)*p(41)
      p(176) = p(5)*p(41)
      p(177) = m(135) + m(136)
      p(178) = p(1)*p(42) - p(177)
      p(179) = p(2)*p(42)
      p(180) = p(3)*p(42)
      p(181) = m(137) + m(138) + m(139) + m(140)
      p(182) = p(4)*p(42) - p(181)
      p(183) = p(5)*p(42)
      p(184) = p(6)*p(33) - p(165)
      p(185) = p(1)*p(43) - p(184)
      p(186) = p(2)*p(43)
      p(187) = p(3)*p(43)
      p(188) = p(6)*p(37) - p(169)
      p(189) = p(4)*p(43) - p(188)
      p(190) = p(5)*p(43)
      p(191) = p(32)*p(7)
      p(192) = p(6)*p(41)
      p(193) = p(6)*p(42)
      p(194) = p(1)*p(44)
      p(195) = p(2)*p(44)
      p(196) = p(3)*p(44)
      p(197) = p(4)*p(44)
      p(198) = p(5)*p(44)
      p(199) = m(141) + m(142)
      p(200) = m(143) + m(144) + m(145) + m(146)
      p(201) = p(6)*p(44) - p(199)
      p(202) = p(10)*p(8)
      p(203) = p(2)*p(45)
      p(204) = p(1)*p(47)
      p(205) = p(2)*p(47)
      p(206) = m(147) + m(148) + m(149) + m(150) + m(151) +m(152)&
     &       + m(153) + m(154)
      p(207) = p(1)*p(48) - p(206)
      p(208) = p(2)*p(48)
      p(209) = m(155) + m(156) + m(157) + m(158) + m(159) + m(160)&
     &       + m(161) + m(162)
      p(210) = m(163) + m(164) + m(165) + m(166)
      p(211) = p(1)*p(49)
      p(212) = p(2)*p(49)
      p(213) = p(14)*p(8)
      p(214) = p(3)*p(48) - p(209)
      p(215) = p(8)*p(15) - p(206)
      p(216) = p(1)*p(50) - p(215)
      p(217) = p(2)*p(50)
      p(218) = p(4)*p(47) - p(209)
      p(219) = p(8)*p(19)
      p(220) = p(8)*p(20)
      p(221) = p(3)*p(50) - p(218)
      p(222) = p(8)*p(22) - p(210)
      p(223) = p(5)*p(45)
      p(224) = p(2)*p(51)
      p(225) = p(5)*p(47)
      p(226) = p(5)*p(48)
      p(227) = p(5)*p(49)
      p(228) = p(5)*p(50)
      p(229) = p(1)*p(52)
      p(230) = p(2)*p(52)
      p(231) = m(167) + m(168) + m(169) + m(170)
      p(232) = m(171) + m(172) + m(173) + m(174) + m(175) + m(176) &
     &       + m(177) + m(178)
      p(233) = p(3)*p(52) - p(231)
      p(234) = p(4)*p(52) - p(232)
      p(235) = p(5)*p(52)
      p(236) = m(179) + m(180) + m(181) + m(182) + m(183) + m(184) &
     &  + m(185) + m(186)
      p(237) = p(1)*p(53) - p(236)
      p(238) = p(2)*p(53)
      p(239) = m(187) + m(188) + m(189) + m(190) + m(191) + m(192) &
     &  + m(193) + m(194)
      p(240) = m(195) + m(196) + m(197) + m(198) + m(199) + m(200) &
     &  + m(201) + m(202)
      p(241) = m(203) + m(204) + m(205) + m(206) + m(207) + m(208) &
     &  + m(209) + m(210)
      p(242) = p(3)*p(53) - p(239)
      p(243) = m(211) + m(212) + m(213) + m(214) + m(215) + m(216) &
     &  + m(217) + m(218)
      p(244) = p(4)*p(53) - p(243) - p(241) - p(240)
      p(245) = p(5)*p(53)
      p(246) = m(219) + m(220) + m(221) + m(222) + m(223) + m(224) &
     &  + m(225) + m(226)
      p(247) = m(227) + m(228) + m(229) + m(230)
      p(248) = p(1)*p(54)
      p(249) = p(2)*p(54)
      p(250) = p(3)*p(54)
      p(251) = p(4)*p(54)
      p(252) = p(5)*p(54)
      p(253) = p(1)*p(55)
      p(254) = p(2)*p(55)
      p(255) = m(231) + m(232)
      p(256) = m(233) + m(234) + m(235) + m(236)
      p(257) = p(3)*p(55) - p(255)
      p(258) = p(4)*p(55) - p(256)
      p(259) = p(5)*p(55)
      p(260) = p(1)*p(56)
      p(261) = p(2)*p(56)
      p(262) = p(6)*p(47) - p(231)
      p(263) = p(6)*p(48) - p(232)
      p(264) = p(3)*p(56) - p(262)
      p(265) = p(4)*p(56) - p(263)
      p(266) = p(5)*p(56)
      p(267) = p(32)*p(8)
      p(268) = p(6)*p(53) - p(246)
      p(269) = p(6)*p(54)
      p(270) = p(6)*p(55)
      p(271) = p(8)*p(33) - p(236)
      p(272) = p(1)*p(57) - p(271)
      p(273) = p(2)*p(57)
      p(274) = p(7)*p(47) - p(239)
      p(275) = m(237) + m(238) + m(239) + m(240) + m(241) + m(242)&
     &  + m(243) + m(244)
      p(276) = p(7)*p(48) - p(275) - p(241) - p(240)
      p(277) = p(3)*p(57) - p(274)
      p(278) = p(8)*p(37) - p(275) - p(243) - p(240)
      p(279) = p(4)*p(57) - p(278) - p(276) - p(275)
      p(280) = p(5)*p(57)
      p(281) = p(7)*p(52) - p(246)
      p(282) = p(8)*p(41)
      p(283) = p(8)*p(42)
      p(284) = p(7)*p(54)
      p(285) = p(7)*p(55)
      p(286) = p(6)*p(57) - p(281)
      p(287) = p(8)*p(44) - p(247)
      p(288) = p(1)*p(58)
      p(289) = p(2)*p(58)
      p(290) = p(3)*p(58)
      p(291) = p(4)*p(58)
      p(292) = p(5)*p(58)
      p(293) = m(245) + m(246)
      p(294) = m(247) + m(248) + m(249) + m(250)
      p(295) = m(251) + m(252) + m(253) + m(254)
      p(296) = p(6)*p(58) - p(293)
      p(297) = p(7)*p(58) - p(294)
      p(298) = p(9)*p(10)
      p(299) = p(2)*p(59)
      p(300) = p(9)*p(12)
      p(301) = p(2)*p(61)
      p(302) = p(9)*p(14)
      p(303) = p(9)*p(15)
      p(304) = p(9)*p(16)
      p(305) = p(2)*p(62)
      p(306) = p(9)*p(18)
      p(307) = p(9)*p(19)
      p(308) = p(9)*p(20)
      p(309) = p(9)*p(21)
      p(310) = p(9)*p(22)
      p(311) = p(5)*p(59)
      p(312) = p(2)*p(63)
      p(313) = p(5)*p(61)
      p(314) = p(5)*p(62)
      p(315) = p(9)*p(27)
      p(316) = p(2)*p(64)
      p(317) = p(9)*p(29)
      p(318) = p(9)*p(30)
      p(319) = p(5)*p(64)
      p(320) = p(9)*p(32)
      p(321) = p(9)*p(33)
      p(322) = p(9)*p(34)
      p(323) = p(2)*p(65)
      p(324) = p(9)*p(36)
      p(325) = p(9)*p(37)
      p(326) = p(9)*p(38)
      p(327) = p(5)*p(65)
      p(328) = p(9)*p(40)
      p(329) = p(9)*p(41)
      p(330) = p(9)*p(42)
      p(331) = p(9)*p(43)
      p(332) = p(9)*p(44)
      p(333) = p(9)*p(45)
      p(334) = p(2)*p(66)
      p(335) = p(9)*p(47)
      p(336) = p(9)*p(48)
      p(337) = p(9)*p(49)
      p(338) = p(9)*p(50)
      p(339) = p(5)*p(66)
      p(340) = p(9)*p(52)
      p(341) = p(9)*p(53)
      p(342) = p(9)*p(54)
      p(343) = p(9)*p(55)
      p(344) = p(9)*p(56)
      p(345) = p(9)*p(57)
      p(346) = p(9)*p(58)
      p(347) = p(10)*p(1)
      p(348) = p(2)*p(67)
      p(349) = p(2)*p(11)
      p(350) = p(3)*p(67)
      p(351) = p(2)*p(13)
      p(352) = p(1)*p(69)
      p(353) = p(2)*p(69)
      p(354) = p(14)*p(3)
      p(355) = p(1)*p(15) - p(81)
      p(356) = p(1)*p(16) - p(81)
      p(357) = p(2)*p(17)
      p(358) = p(3)*p(18) - p(95)
      p(359) = p(3)*p(21) - p(95)
      p(360) = p(4)*p(15) - p(98) - p(89) - p(87) - p(89)
      p(361) = p(1)*p(70) - p(360)
      p(362) = p(2)*p(70)
      p(363) = p(4)*p(18) - p(100) - p(97) - p(96) - p(100)
      p(364) = p(4)*p(19) - p(101)
      p(365) = p(4)*p(20) - p(101)
      p(366) = p(3)*p(70) - p(363)
      p(367) = p(4)*p(22) - p(101)
      p(368) = p(5)*p(67)
      p(369) = p(2)*p(24)
      p(370) = p(5)*p(69)
      p(371) = p(5)*p(70)
      p(372) = p(5)*p(23)
      p(373) = p(2)*p(71)
      p(374) = p(5)*p(25)
      p(375) = p(5)*p(26)
      p(376) = p(6)*p(67)
      p(377) = p(2)*p(28)
      p(378) = p(6)*p(69)
      p(379) = p(6)*p(70)
      p(380) = p(5)*p(31)
      p(381) = p(1)*p(72)
      p(382) = p(2)*p(72)
      p(383) = p(3)*p(72)
      p(384) = p(4)*p(72)
      p(385) = p(5)*p(72)
      p(386) = p(32)*p(6)
      p(387) = p(1)*p(33) - p(138)
      p(388) = p(1)*p(34) - p(138)
      p(389) = p(2)*p(35)
      p(390) = p(7)*p(69)
      p(391) = p(4)*p(37) - p(158) - p(155) - p(149) - p(149)
      p(392) = p(7)*p(70) - p(391)
      p(393) = p(5)*p(39)
      p(394) = p(6)*p(40) - p(191)
      p(395) = p(6)*p(43) - p(191)
      p(396) = p(7)*p(33) - p(194) - p(177) - p(172) - p(177)
      p(397) = p(1)*p(73) - p(396)
      p(398) = p(2)*p(73)
      p(399) = p(3)*p(73)
      p(400) = p(7)*p(37) - p(197) - p(181) - p(175) - p(181)
      p(401) = p(4)*p(73) - p(400)
      p(402) = p(5)*p(73)
      p(403) = p(7)*p(40) - p(199) - p(193) - p(192) - p(199)
      p(404) = p(7)*p(41) - p(200)
      p(405) = p(7)*p(42) - p(200)
      p(406) = p(6)*p(73) - p(403)
      p(407) = p(7)*p(44) - p(200)
      p(408) = p(8)*p(67)
      p(409) = p(2)*p(46)
      p(410) = p(3)*p(47) - p(213)
      p(411) = p(4)*p(48) - p(220) - p(219) - p(210) - p(210)
      p(412) = p(3)*p(49) - p(213)
      p(413) = p(8)*p(70) - p(411)
      p(414) = p(5)*p(51)
      p(415) = p(6)*p(52) - p(267)
      p(416) = p(7)*p(53) - p(283) - p(282) - p(247) - p(247)
      p(417) = p(6)*p(56) - p(267)
      p(418) = p(8)*p(73) - p(416)
      p(419) = p(1)*p(74)
      p(420) = p(2)*p(74)
      p(421) = p(8)*p(47) - p(290) - p(255) - p(250) - p(255)
      p(422) = p(8)*p(48) - p(291) - p(256) - p(251) - p(256)
      p(423) = p(3)*p(74) - p(421)
      p(424) = p(4)*p(74) - p(422)
      p(425) = p(5)*p(74)
      p(426) = p(8)*p(52) - p(293) - p(270) - p(269) - p(293)
      p(427) = p(8)*p(53) - p(294) - p(285) - p(284) - p(294)
      p(428) = p(8)*p(54) - p(295)
      p(429) = p(8)*p(55) - p(295)
      p(430) = p(6)*p(74) - p(426)
      p(431) = p(7)*p(74) - p(427)
      p(432) = p(8)*p(58) - p(295)
      p(433) = p(9)*p(67)
      p(434) = p(2)*p(60)
      p(435) = p(9)*p(69)
      p(436) = p(9)*p(70)
      p(437) = p(5)*p(63)
      p(438) = p(9)*p(72)
      p(439) = p(9)*p(73)
      p(440) = p(9)*p(74)
      p(441) = p(9)*p(59)
      p(442) = p(2)*p(75)
      p(443) = p(9)*p(61)
      p(444) = p(9)*p(62)
      p(445) = p(5)*p(75)
      p(446) = p(9)*p(64)
      p(447) = p(9)*p(65)
      p(448) = p(9)*p(66)
      p(449) = p(1)*p(67) - p(347)
      p(450) = p(2)*p(68)
      p(451) = p(3)*p(69) - p(354)
      p(452) = p(4)*p(70) - p(367) - p(365) - p(364)
      p(453) = p(5)*p(71)
      p(454) = p(6)*p(72) - p(386)
      p(455) = p(7)*p(73) - p(407) - p(405) - p(404)
      p(456) = p(8)*p(74) - p(432) - p(429) - p(428)
      p(457) = p(9)*p(75)
      p(458) = p(2)*p(77)
      p(459) = p(10)*p(14)
      p(460) = p(2)*p(79)
      p(461) = p(2)*p(81)
      p(462) = p(10)*p(18)
      p(463) = p(2)*p(84)
      p(464) = p(2)*p(85)
      p(465) = p(10)*p(19)
      p(466) = p(2)*p(87)
      p(467) = p(10)*p(20)
      p(468) = p(2)*p(89)
      p(469) = p(2)*p(90)
      p(470) = p(10)*p(21)
      p(471) = p(2)*p(92)
      p(472) = p(2)*p(93)
      p(473) = p(14)*p(15)
      p(474) = p(14)*p(16)
      p(475) = p(2)*p(95)
      p(476) = m(255) + m(256) + m(257) + m(258)
      p(477) = p(1)*p(96) - p(476)
      p(478) = p(2)*p(96)
      p(479) = p(14)*p(19)
      p(480) = p(3)*p(89)
      p(481) = p(3)*p(90)
      p(482) = p(2)*p(97)
      p(483) = p(14)*p(20)
      p(484) = p(10)*p(22)
      p(485) = p(2)*p(98)
      p(486) = p(1)*p(100)
      p(487) = p(2)*p(100)
      p(488) = m(259) + m(260) + m(261) + m(262)
      p(489) = p(1)*p(101) - p(488)
      p(490) = p(2)*p(101)
      p(491) = m(263) + m(264) + m(265) + m(266)
      p(492) = m(267)
      p(493) = p(1)*p(102)
      p(494) = p(2)*p(102)
      p(495) = p(14)*p(22)
      p(496) = p(3)*p(101) - p(491)
      p(497) = p(2)*p(103)
      p(498) = p(5)*p(77)
      p(499) = p(2)*p(105)
      p(500) = p(5)*p(79)
      p(501) = p(2)*p(107)
      p(502) = p(5)*p(81)
      p(503) = p(2)*p(108)
      p(504) = p(2)*p(109)
      p(505) = p(5)*p(84)
      p(506) = p(5)*p(85)
      p(507) = p(2)*p(111)
      p(508) = p(5)*p(87)
      p(509) = p(2)*p(112)
      p(510) = p(5)*p(89)
      p(511) = p(5)*p(90)
      p(512) = p(2)*p(113)
      p(513) = p(5)*p(92)
      p(514) = p(5)*p(93)
      p(515) = p(2)*p(114)
      p(516) = p(5)*p(95)
      p(517) = p(5)*p(96)
      p(518) = p(5)*p(97)
      p(519) = p(5)*p(98)
      p(520) = p(2)*p(115)
      p(521) = p(5)*p(100)
      p(522) = p(5)*p(101)
      p(523) = p(5)*p(102)
      p(524) = p(2)*p(116)
      p(525) = p(10)*p(29)
      p(526) = p(2)*p(118)
      p(527) = p(14)*p(27)
      p(528) = p(2)*p(120)
      p(529) = p(10)*p(30)
      p(530) = p(2)*p(121)
      p(531) = p(2)*p(122)
      p(532) = p(6)*p(84)
      p(533) = p(6)*p(85)
      p(534) = p(2)*p(124)
      p(535) = p(1)*p(125)
      p(536) = p(2)*p(125)
      p(537) = p(6)*p(89)
      p(538) = p(6)*p(90)
      p(539) = p(2)*p(126)
      p(540) = p(6)*p(92)
      p(541) = p(6)*p(93)
      p(542) = p(2)*p(127)
      p(543) = p(14)*p(30)
      p(544) = p(3)*p(125)
      p(545) = p(3)*p(126)
      p(546) = p(1)*p(128)
      p(547) = p(2)*p(128)
      p(548) = p(6)*p(100)
      p(549) = p(6)*p(101)
      p(550) = p(6)*p(102)
      p(551) = p(5)*p(116)
      p(552) = p(2)*p(129)
      p(553) = p(5)*p(118)
      p(554) = p(2)*p(131)
      p(555) = p(5)*p(120)
      p(556) = p(5)*p(121)
      p(557) = p(5)*p(122)
      p(558) = p(2)*p(132)
      p(559) = p(5)*p(124)
      p(560) = p(5)*p(125)
      p(561) = p(5)*p(126)
      p(562) = p(5)*p(127)
      p(563) = p(5)*p(128)
      p(564) = p(10)*p(32)
      p(565) = p(2)*p(133)
      p(566) = p(32)*p(12)
      p(567) = p(2)*p(135)
      p(568) = p(14)*p(32)
      p(569) = p(32)*p(15)
      p(570) = p(32)*p(16)
      p(571) = p(2)*p(136)
      p(572) = p(32)*p(18)
      p(573) = p(32)*p(19)
      p(574) = p(32)*p(20)
      p(575) = p(32)*p(21)
      p(576) = p(32)*p(22)
      p(577) = p(5)*p(133)
      p(578) = p(2)*p(137)
      p(579) = p(5)*p(135)
      p(580) = p(5)*p(136)
      p(581) = p(2)*p(138)
      p(582) = p(10)*p(36)
      p(583) = p(2)*p(141)
      p(584) = p(2)*p(142)
      p(585) = p(14)*p(33)
      p(586) = p(14)*p(34)
      p(587) = p(2)*p(144)
      p(588) = p(10)*p(37)
      p(589) = p(2)*p(145)
      p(590) = p(2)*p(146)
      p(591) = m(268) + m(269) + m(270) + m(271) + m(272) + m(273)& 
     &  + m(274) + m(275)
      p(592) = p(1)*p(148) - p(591)
      p(593) = p(2)*p(148)
      p(594) = m(276) + m(277) + m(278) + m(279)
      p(595) = p(1)*p(149) - p(594)
      p(596) = p(2)*p(149)
      p(597) = p(3)*p(145) - p(591)
      p(598) = p(1)*p(150) - p(597)
      p(599) = p(2)*p(150)
      p(600) = p(14)*p(37)
      p(601) = p(3)*p(149)
      p(602) = p(10)*p(38)
      p(603) = p(2)*p(151)
      p(604) = p(2)*p(152)
      p(605) = p(7)*p(84) - p(592)
      p(606) = p(1)*p(154) - p(605)
      p(607) = p(2)*p(154)
      p(608) = p(19)*p(33)
      p(609) = p(19)*p(34)
      p(610) = p(2)*p(155)
      p(611) = m(280) + m(281) + m(282) + m(283) + m(284) + m(285) &
     &  + m(286) + m(287)
      p(612) = p(7)*p(89) - p(595)
      p(613) = p(1)*p(156) - p(612)
      p(614) = p(2)*p(156)
      p(615) = p(3)*p(151) - p(605)
      p(616) = p(1)*p(157) - p(615)
      p(617) = p(2)*p(157)
      p(618) = p(14)*p(38)
      p(619) = p(3)*p(155) - p(611)
      p(620) = p(3)*p(156)
      p(621) = p(22)*p(33)
      p(622) = p(22)*p(34)
      p(623) = p(2)*p(158)
      p(624) = p(7)*p(100)
      p(625) = m(288) + m(289) + m(290) + m(291) + m(292) + m(293) &
     &  + m(294) + m(295)
      p(626) = p(7)*p(101) - p(625)
      p(627) = p(7)*p(102)
      p(628) = p(5)*p(138)
      p(629) = p(2)*p(159)
      p(630) = p(2)*p(160)
      p(631) = p(5)*p(141)
      p(632) = p(5)*p(142)
      p(633) = p(2)*p(162)
      p(634) = p(5)*p(144)
      p(635) = p(5)*p(145)
      p(636) = p(5)*p(146)
      p(637) = p(2)*p(163)
      p(638) = p(5)*p(148)
      p(639) = p(5)*p(149)
      p(640) = p(5)*p(150)
      p(641) = p(5)*p(151)
      p(642) = p(5)*p(152)
      p(643) = p(2)*p(164)
      p(644) = p(5)*p(154)
      p(645) = p(5)*p(155)
      p(646) = p(5)*p(156)
      p(647) = p(5)*p(157)
      p(648) = p(5)*p(158)
      p(649) = p(10)*p(40)
      p(650) = p(2)*p(165)
      p(651) = p(2)*p(166)
      p(652) = p(3)*p(165)
      p(653) = p(3)*p(166)
      p(654) = p(2)*p(168)
      p(655) = p(14)*p(40)
      p(656) = m(296) + m(297) + m(298) + m(299) + m(300) + m(301) &
     &  + m(302) + m(303)
      p(657) = p(1)*p(169) - p(656)
      p(658) = p(2)*p(169)
      p(659) = m(304) + m(305) + m(306) + m(307) + m(308) + m(309) &
     &  + m(310) + m(311)
      p(660) = m(312) + m(313) + m(314) + m(315)
      p(661) = p(3)*p(169) - p(659)
      p(662) = p(4)*p(165) - p(656)
      p(663) = p(1)*p(170) - p(662)
      p(664) = p(2)*p(170)
      p(665) = p(18)*p(40) - p(659)
      p(666) = p(19)*p(40)
      p(667) = p(20)*p(40) - p(660)
      p(668) = p(3)*p(170) - p(665)
      p(669) = p(22)*p(40)
      p(670) = p(5)*p(165)
      p(671) = p(5)*p(166)
      p(672) = p(2)*p(171)
      p(673) = p(5)*p(168)
      p(674) = p(5)*p(169)
      p(675) = p(5)*p(170)
      p(676) = p(10)*p(41)
      p(677) = p(2)*p(172)
      p(678) = p(1)*p(174)
      p(679) = p(2)*p(174)
      p(680) = p(14)*p(41)
      p(681) = p(15)*p(41)
      p(682) = p(16)*p(41)
      p(683) = p(2)*p(175)
      p(684) = p(18)*p(41)
      p(685) = p(19)*p(41)
      p(686) = p(20)*p(41)
      p(687) = p(21)*p(41)
      p(688) = p(22)*p(41)
      p(689) = p(5)*p(172)
      p(690) = p(2)*p(176)
      p(691) = p(5)*p(174)
      p(692) = p(5)*p(175)
      p(693) = p(10)*p(42)
      p(694) = p(2)*p(177)
      p(695) = p(2)*p(178)
      p(696) = p(3)*p(177)
      p(697) = p(3)*p(178)
      p(698) = p(2)*p(180)
      p(699) = p(14)*p(42)
      p(700) = m(316) + m(317) + m(318) + m(319)
      p(701) = p(1)*p(181) - p(700)
      p(702) = p(2)*p(181)
      p(703) = m(320) + m(321) + m(322) + m(323)
      p(704) = m(324) + m(325)
      p(705) = p(3)*p(181) - p(703)
      p(706) = p(4)*p(177) - p(700)
      p(707) = p(1)*p(182) - p(706)
      p(708) = p(2)*p(182)
      p(709) = p(18)*p(42) - p(703)
      p(710) = p(19)*p(42)
      p(711) = p(20)*p(42) - p(704)
      p(712) = p(3)*p(182) - p(709)
      p(713) = p(22)*p(42)
      p(714) = p(5)*p(177)
      p(715) = p(5)*p(178)
      p(716) = p(2)*p(183)
      p(717) = p(5)*p(180)
      p(718) = p(5)*p(181)
      p(719) = p(5)*p(182)
      p(720) = p(10)*p(43)
      p(721) = p(2)*p(184)
      p(722) = p(2)*p(185)
      p(723) = p(3)*p(184)
      p(724) = p(3)*p(185)
      p(725) = p(2)*p(187)
      p(726) = p(14)*p(43)
      p(727) = p(6)*p(145) - p(656)
      p(728) = p(1)*p(188) - p(727)
      p(729) = p(2)*p(188)
      p(730) = p(6)*p(148) - p(659)
      p(731) = p(6)*p(149) - p(660)
      p(732) = p(3)*p(188) - p(730)
      p(733) = p(4)*p(184) - p(727)
      p(734) = p(1)*p(189) - p(733)
      p(735) = p(2)*p(189)
      p(736) = p(6)*p(154) - p(665)
      p(737) = p(19)*p(43)
      p(738) = p(6)*p(156) - p(667)
      p(739) = p(3)*p(189) - p(736)
      p(740) = p(22)*p(43)
      p(741) = p(5)*p(184)
      p(742) = p(5)*p(185)
      p(743) = p(2)*p(190)
      p(744) = p(5)*p(187)
      p(745) = p(5)*p(188)
      p(746) = p(5)*p(189)
      p(747) = p(32)*p(33)
      p(748) = p(32)*p(34)
      p(749) = p(2)*p(191)
      p(750) = p(32)*p(36)
      p(751) = p(32)*p(37)
      p(752) = p(32)*p(38)
      p(753) = p(5)*p(191)
      p(754) = m(326) + m(327) + m(328) + m(329)
      p(755) = p(1)*p(192) - p(754)
      p(756) = p(2)*p(192)
      p(757) = p(3)*p(192)
      p(758) = m(330) + m(331) + m(332) + m(333) + m(334) + m(335) &
     &  + m(336) + m(337)
      p(759) = p(4)*p(192) - p(758)
      p(760) = p(5)*p(192)
      p(761) = p(32)*p(41)
      p(762) = p(6)*p(177)
      p(763) = p(6)*p(178)
      p(764) = p(2)*p(193)
      p(765) = p(3)*p(193)
      p(766) = p(6)*p(181)
      p(767) = p(6)*p(182)
      p(768) = p(5)*p(193)
      p(769) = p(32)*p(42)
      p(770) = p(10)*p(44)
      p(771) = p(2)*p(194)
      p(772) = p(1)*p(196)
      p(773) = p(2)*p(196)
      p(774) = p(14)*p(44)
      p(775) = p(15)*p(44)
      p(776) = p(16)*p(44)
      p(777) = p(2)*p(197)
      p(778) = p(18)*p(44)
      p(779) = p(19)*p(44)
      p(780) = p(20)*p(44)
      p(781) = p(21)*p(44)
      p(782) = p(22)*p(44)
      p(783) = p(5)*p(194)
      p(784) = p(2)*p(198)
      p(785) = p(5)*p(196)
      p(786) = p(5)*p(197)
      p(787) = p(1)*p(199)
      p(788) = p(2)*p(199)
      p(789) = p(3)*p(199)
      p(790) = p(4)*p(199)
      p(791) = p(5)*p(199)
      p(792) = m(338) + m(339) + m(340) + m(341)
      p(793) = p(1)*p(200) - p(792)
      p(794) = p(2)*p(200)
      p(795) = p(3)*p(200)
      p(796) = m(342) + m(343) + m(344) + m(345) + m(346) + m(347)&
     &  + m(348) + m(349)
      p(797) = p(4)*p(200) - p(796)
      p(798) = p(5)*p(200)
      p(799) = m(350) + m(351) + m(352) + m(353)
      p(800) = m(354)
      p(801) = p(1)*p(201)
      p(802) = p(2)*p(201)
      p(803) = p(3)*p(201)
      p(804) = p(4)*p(201)
      p(805) = p(5)*p(201)
      p(806) = p(32)*p(44)
      p(807) = p(6)*p(200) - p(799)
      p(808) = p(2)*p(202)
      p(809) = p(10)*p(47)
      p(810) = p(2)*p(204)
      p(811) = p(10)*p(48)
      p(812) = p(2)*p(206)
      p(813) = p(2)*p(207)
      p(814) = m(355) + m(356) + m(357) + m(358) + m(359) + m(360) &
     &  + m(361) + m(362)
      p(815) = p(1)*p(209) - p(814)
      p(816) = p(2)*p(209)
      p(817) = p(1)*p(210)
      p(818) = p(2)*p(210)
      p(819) = m(363) + m(364) + m(365) + m(366)
      p(820) = p(10)*p(49)
      p(821) = p(2)*p(211)
      p(822) = p(14)*p(45)
      p(823) = p(2)*p(213)
      p(824) = p(3)*p(206) - p(814)
      p(825) = p(1)*p(214) - p(824)
      p(826) = p(2)*p(214)
      p(827) = p(14)*p(48)
      p(828) = p(3)*p(210) - p(819)
      p(829) = p(10)*p(50)
      p(830) = p(2)*p(215)
      p(831) = p(2)*p(216)
      p(832) = p(8)*p(84) - p(824)
      p(833) = p(1)*p(218) - p(832)
      p(834) = p(2)*p(218)
      p(835) = m(367) + m(368) + m(369) + m(370) + m(371) + m(372)&
     &  + m(373) + m(374)
      p(836) = p(1)*p(219) - p(835)
      p(837) = p(2)*p(219)
      p(838) = p(19)*p(47)
      p(839) = p(8)*p(89)
      p(840) = p(8)*p(90)
      p(841) = p(2)*p(220)
      p(842) = p(20)*p(47)
      p(843) = m(375) + m(376) + m(377) + m(378) + m(379) + m(380) &
     &  + m(381) + m(382)
      p(844) = p(3)*p(215) - p(832)
      p(845) = p(1)*p(221) - p(844)
      p(846) = p(2)*p(221)
      p(847) = p(14)*p(50)
      p(848) = p(19)*p(49)
      p(849) = p(20)*p(49)
      p(850) = p(1)*p(222)
      p(851) = p(2)*p(222)
      p(852) = p(8)*p(100) - p(828)
      p(853) = p(8)*p(101) - p(843)
      p(854) = p(3)*p(222) - p(852)
      p(855) = p(5)*p(202)
      p(856) = p(2)*p(223)
      p(857) = p(5)*p(204)
      p(858) = p(2)*p(225)
      p(859) = p(5)*p(206)
      p(860) = p(5)*p(207)
      p(861) = p(2)*p(226)
      p(862) = p(5)*p(209)
      p(863) = p(5)*p(210)
      p(864) = p(5)*p(211)
      p(865) = p(2)*p(227)
      p(866) = p(5)*p(213)
      p(867) = p(5)*p(214)
      p(868) = p(5)*p(215)
      p(869) = p(5)*p(216)
      p(870) = p(2)*p(228)
      p(871) = p(5)*p(218)
      p(872) = p(5)*p(219)
      p(873) = p(5)*p(220)
      p(874) = p(5)*p(221)
      p(875) = p(5)*p(222)
      p(876) = p(10)*p(52)
      p(877) = p(2)*p(229)
      p(878) = p(1)*p(231)
      p(879) = p(2)*p(231)
      p(880) = m(383) + m(384) + m(385) + m(386) + m(387) + m(388) &
     &  + m(389) + m(390)
      p(881) = p(1)*p(232) - p(880)
      p(882) = p(2)*p(232)
      p(883) = m(391) + m(392) + m(393) + m(394) + m(395) + m(396) &
     &  + m(397) + m(398)
      p(884) = m(399) + m(400) + m(401) + m(402)
      p(885) = p(1)*p(233)
      p(886) = p(2)*p(233)
      p(887) = p(14)*p(52)
      p(888) = p(3)*p(232) - p(883)
      p(889) = p(15)*p(52) - p(880)
      p(890) = p(1)*p(234) - p(889)
      p(891) = p(2)*p(234)
      p(892) = p(4)*p(231) - p(883)
      p(893) = p(19)*p(52)
      p(894) = p(20)*p(52)
      p(895) = p(3)*p(234) - p(892)
      p(896) = p(22)*p(52) - p(884)
      p(897) = p(5)*p(229)
      p(898) = p(2)*p(235)
      p(899) = p(5)*p(231)
      p(900) = p(5)*p(232)
      p(901) = p(5)*p(233)
      p(902) = p(5)*p(234)
      p(903) = p(10)*p(53)
      p(904) = p(2)*p(236)
      p(905) = p(2)*p(237)
      p(906) = m(403) + m(404) + m(405) + m(406) + m(407) + m(408) &
     &  + m(409) + m(410)
      p(907) = p(1)*p(239) - p(906)
      p(908) = p(2)*p(239)
      p(909) = m(411) + m(412) + m(413) + m(414) + m(415) + m(416) &
     &  + m(417) + m(418)
      p(910) = p(1)*p(240) - p(909)
      p(911) = p(2)*p(240)
      p(912) = m(419) + m(420) + m(421) + m(422) + m(423) + m(424) &
     &  + m(425) + m(426)
      p(913) = m(427) + m(428) + m(429) + m(430) + m(431) + m(432) &
     &  + m(433) + m(434)
      p(914) = p(1)*p(241) - p(913)
      p(915) = p(2)*p(241)
      p(916) = m(435) + m(436) + m(437) + m(438) + m(439) + m(440) &
     &  + m(441) + m(442)
      p(917) = m(443) + m(444) + m(445) + m(446) + m(447) + m(448) &
     &  + m(449) + m(450)
      p(918) = p(3)*p(236) - p(906)
      p(919) = p(1)*p(242) - p(918)
      p(920) = p(2)*p(242)
      p(921) = p(14)*p(53)
      p(922) = p(3)*p(240) - p(912)
      p(923) = p(3)*p(241) - p(916)
      p(924) = m(451) + m(452) + m(453) + m(454) + m(455) + m(456) & 
     &  + m(457) + m(458)
      p(925) = p(1)*p(243) - p(924)
      p(926) = p(2)*p(243)
      p(927) = m(459) + m(460) + m(461) + m(462) + m(463) + m(464) &
     &  + m(465) + m(466)
      p(928) = m(467) + m(468) + m(469) + m(470) + m(471) + m(472) &
     &  + m(473) + m(474)
      p(929) = m(475) + m(476) + m(477) + m(478) + m(479) + m(480) &
     &  + m(481) + m(482)
      p(930) = p(3)*p(243) - p(927)
      p(931) = p(4)*p(236) - p(924) - p(913) - p(909)
      p(932) = p(1)*p(244) - p(931)
      p(933) = p(2)*p(244)
      p(934) = p(4)*p(239) - p(927) - p(916) - p(912)
      p(935) = p(19)*p(53) - p(929)
      p(936) = p(20)*p(53) - p(928)
      p(937) = p(3)*p(244) - p(934)
      p(938) = p(22)*p(53) - p(917)
      p(939) = p(5)*p(236)
      p(940) = p(5)*p(237)
      p(941) = p(2)*p(245)
      p(942) = p(5)*p(239)
      p(943) = p(5)*p(240)
      p(944) = p(5)*p(241)
      p(945) = p(5)*p(242)
      p(946) = p(5)*p(243)
      p(947) = p(5)*p(244)
      p(948) = m(483) + m(484) + m(485) + m(486) + m(487) + m(488) &
     &  + m(489) + m(490)
      p(949) = p(1)*p(246) - p(948)
      p(950) = p(2)*p(246)
      p(951) = m(491) + m(492) + m(493) + m(494) + m(495) + m(496) &
     &  + m(497) + m(498)
      p(952) = m(499) + m(500) + m(501) + m(502) + m(503) + m(504) &
     &  + m(505) + m(506)
      p(953) = m(507) + m(508) + m(509) + m(510) + m(511) + m(512) &
     &  + m(513) + m(514)
      p(954) = p(3)*p(246) - p(951)
      p(955) = m(515) + m(516) + m(517) + m(518) + m(519) + m(520) &
     &  + m(521) + m(522)
      p(956) = p(4)*p(246) - p(955) - p(953) - p(952)
      p(957) = p(5)*p(246)
      p(958) = p(1)*p(247)
      p(959) = p(2)*p(247)
      p(960) = m(523) + m(524) + m(525) + m(526)
      p(961) = m(527) + m(528) + m(529) + m(530) + m(531) + m(532) &
     &  + m(533) + m(534)
      p(962) = p(3)*p(247) - p(960)
      p(963) = p(4)*p(247) - p(961)
      p(964) = p(5)*p(247)
      p(965) = m(535) + m(536) + m(537) + m(538)
      p(966) = p(10)*p(54)
      p(967) = p(2)*p(248)
      p(968) = p(1)*p(250)
      p(969) = p(2)*p(250)
      p(970) = p(14)*p(54)
      p(971) = p(15)*p(54)
      p(972) = p(16)*p(54)
      p(973) = p(2)*p(251)
      p(974) = p(18)*p(54)
      p(975) = p(19)*p(54)
      p(976) = p(20)*p(54)
      p(977) = p(21)*p(54)
      p(978) = p(22)*p(54)
      p(979) = p(5)*p(248)
      p(980) = p(2)*p(252)
      p(981) = p(5)*p(250)
      p(982) = p(5)*p(251)
      p(983) = p(10)*p(55)
      p(984) = p(2)*p(253)
      p(985) = p(1)*p(255)
      p(986) = p(2)*p(255)
      p(987) = m(539) + m(540) + m(541) + m(542)
      p(988) = p(1)*p(256) - p(987)
      p(989) = p(2)*p(256)
      p(990) = m(543) + m(544) + m(545) + m(546)
      p(991) = m(547) + m(548)
      p(992) = p(1)*p(257)
      p(993) = p(2)*p(257)
      p(994) = p(14)*p(55)
      p(995) = p(3)*p(256) - p(990)
      p(996) = p(15)*p(55) - p(987)
      p(997) = p(1)*p(258) - p(996)
      p(998) = p(2)*p(258)
      p(999) = p(4)*p(255) - p(990)
      p(1000) = p(19)*p(55)
      p(1001) = p(20)*p(55)
      p(1002) = p(3)*p(258) - p(999)
      p(1003) = p(22)*p(55) - p(991)
      p(1004) = p(5)*p(253)
      p(1005) = p(2)*p(259)
      p(1006) = p(5)*p(255)
      p(1007) = p(5)*p(256)
      p(1008) = p(5)*p(257)
      p(1009) = p(5)*p(258)
      p(1010) = p(10)*p(56)
      p(1011) = p(2)*p(260)
      p(1012) = p(1)*p(262)
      p(1013) = p(2)*p(262)
      p(1014) = p(6)*p(206) - p(880)
      p(1015) = p(1)*p(263) - p(1014)
      p(1016) = p(2)*p(263)
      p(1017) = p(6)*p(209) - p(883)
      p(1018) = p(6)*p(210) - p(884)
      p(1019) = p(1)*p(264)
      p(1020) = p(2)*p(264)
      p(1021) = p(14)*p(56)
      p(1022) = p(3)*p(263) - p(1017)
      p(1023) = p(6)*p(215) - p(889)
      p(1024) = p(1)*p(265) - p(1023)
      p(1025) = p(2)*p(265)
      p(1026) = p(4)*p(262) - p(1017)
      p(1027) = p(19)*p(56)
      p(1028) = p(20)*p(56)
      p(1029) = p(3)*p(265) - p(1026)
      p(1030) = p(6)*p(222) - p(896)
      p(1031) = p(5)*p(260)
      p(1032) = p(2)*p(266)
      p(1033) = p(5)*p(262)
      p(1034) = p(5)*p(263)
      p(1035) = p(5)*p(264)
      p(1036) = p(5)*p(265)
      p(1037) = p(32)*p(45)
      p(1038) = p(2)*p(267)
      p(1039) = p(32)*p(47)
      p(1040) = p(32)*p(48)
      p(1041) = p(32)*p(49)
      p(1042) = p(32)*p(50)
      p(1043) = p(5)*p(267)
      p(1044) = p(6)*p(236) - p(948)
      p(1045) = p(1)*p(268) - p(1044)
      p(1046) = p(2)*p(268)
      p(1047) = p(6)*p(239) - p(951)
      p(1048) = p(6)*p(240) - p(952)
      p(1049) = p(6)*p(241) - p(953)
      p(1050) = p(3)*p(268) - p(1047)
      p(1051) = p(6)*p(243) - p(955)
      p(1052) = p(6)*p(244) - p(956)
      p(1053) = p(5)*p(268)
      p(1054) = p(32)*p(53)
      p(1055) = p(6)*p(247) - p(965)
      p(1056) = p(1)*p(269)
      p(1057) = p(2)*p(269)
      p(1058) = m(549) + m(550) + m(551) + m(552)
      p(1059) = m(553) + m(554) + m(555) + m(556) + m(557) + m(558) &
     &  + m(559) + m(560)
      p(1060) = p(3)*p(269) - p(1058)
      p(1061) = p(4)*p(269) - p(1059)
      p(1062) = p(5)*p(269)
      p(1063) = p(32)*p(54)
      p(1064) = p(1)*p(270)
      p(1065) = p(2)*p(270)
      p(1066) = p(6)*p(255)
      p(1067) = p(6)*p(256)
      p(1068) = p(6)*p(257)
      p(1069) = p(6)*p(258)
      p(1070) = p(5)*p(270)
      p(1071) = p(32)*p(55)
      p(1072) = p(10)*p(57)
      p(1073) = p(2)*p(271)
      p(1074) = p(2)*p(272)
      p(1075) = p(33)*p(47) - p(906)
      p(1076) = p(1)*p(274) - p(1075)
      p(1077) = p(2)*p(274)
      p(1078) = m(561) + m(562) + m(563) + m(564) + m(565) + m(566) &
     &  + m(567) + m(568)
      p(1079) = p(1)*p(275) - p(1078)
      p(1080) = p(2)*p(275)
      p(1081) = m(569) + m(570) + m(571) + m(572) + m(573) + m(574) &
     &  + m(575) + m(576)
      p(1082) = p(7)*p(206) - p(1079) - p(913) - p(910)
      p(1083) = p(1)*p(276) - p(1082)
      p(1084) = p(2)*p(276)
      p(1085) = p(7)*p(209) - p(1081) - p(916) - p(912)
      p(1086) = p(7)*p(210) - p(917)
      p(1087) = p(3)*p(271) - p(1075)
      p(1088) = p(1)*p(277) - p(1087)
      p(1089) = p(2)*p(277)
      p(1090) = p(14)*p(57)
      p(1091) = p(3)*p(275) - p(1081)
      p(1092) = p(3)*p(276) - p(1085)
      p(1093) = p(8)*p(145) - p(1078) - p(924) - p(909)
      p(1094) = p(1)*p(278) - p(1093)
      p(1095) = p(2)*p(278)
      p(1096) = p(8)*p(148) - p(1091) - p(927) - p(922)
      p(1097) = p(8)*p(149) - p(928)
      p(1098) = m(577) + m(578) + m(579) + m(580) + m(581) + m(582) &
     &  + m(583) + m(584)
      p(1099) = p(3)*p(278) - p(1096)
      p(1100) = p(4)*p(271) - p(1093) - p(1082) - p(1078)
      p(1101) = p(1)*p(279) - p(1100)
      p(1102) = p(2)*p(279)
      p(1103) = p(4)*p(274) - p(1096) - p(1085) - p(1081)
      p(1104) = p(19)*p(57) - p(1098)
      p(1105) = p(8)*p(156) - p(936)
      p(1106) = p(3)*p(279) - p(1103)
      p(1107) = p(7)*p(222) - p(938)
      p(1108) = p(5)*p(271)
      p(1109) = p(5)*p(272)
      p(1110) = p(2)*p(280)
      p(1111) = p(5)*p(274)
      p(1112) = p(5)*p(275)
      p(1113) = p(5)*p(276)
      p(1114) = p(5)*p(277)
      p(1115) = p(5)*p(278)
      p(1116) = p(5)*p(279)
      p(1117) = p(8)*p(165) - p(1044)
      p(1118) = p(1)*p(281) - p(1117)
      p(1119) = p(2)*p(281)
      p(1120) = p(7)*p(231) - p(951)
      p(1121) = m(585) + m(586) + m(587) + m(588) + m(589) + m(590) &
     &  + m(591) + m(592)
      p(1122) = p(7)*p(232) - p(1121) - p(953) - p(952)
      p(1123) = p(3)*p(281) - p(1120)
      p(1124) = p(8)*p(169) - p(1121) - p(1051) - p(1048)
      p(1125) = p(4)*p(281) - p(1124) - p(1122) - p(1121)
      p(1126) = p(5)*p(281)
      p(1127) = m(593) + m(594) + m(595) + m(596) + m(597) + m(598) &
     &  + m(599) + m(600)
      p(1128) = p(1)*p(282) - p(1127)
      p(1129) = p(2)*p(282)
      p(1130) = p(41)*p(47)
      p(1131) = m(601) + m(602) + m(603) + m(604) + m(605) + m(606) &
     &  + m(607) + m(608)
      p(1132) = p(41)*p(48) - p(1131)
      p(1133) = p(41)*p(49)
      p(1134) = m(609) + m(610) + m(611) + m(612) + m(613) + m(614) &
     &  + m(615) + m(616)
      p(1135) = p(41)*p(50) - p(1134)
      p(1136) = p(5)*p(282)
      p(1137) = p(41)*p(52)
      p(1138) = p(8)*p(177)
      p(1139) = p(8)*p(178)
      p(1140) = p(2)*p(283)
      p(1141) = p(42)*p(47)
      p(1142) = m(617) + m(618) + m(619) + m(620) + m(621) + m(622) &
     &  + m(623) + m(624)
      p(1143) = p(42)*p(48) - p(1142)
      p(1144) = p(42)*p(49)
      p(1145) = p(8)*p(181) - p(1142)
      p(1146) = p(8)*p(182) - p(1143)
      p(1147) = p(5)*p(283)
      p(1148) = p(42)*p(52)
      p(1149) = m(625) + m(626) + m(627) + m(628) + m(629) + m(630) &
     &  + m(631) + m(632)
      p(1150) = p(33)*p(54)
      p(1151) = p(34)*p(54)
      p(1152) = p(2)*p(284)
      p(1153) = m(633) + m(634) + m(635) + m(636) + m(637) + m(638) &
     &  + m(639) + m(640)
      p(1154) = m(641) + m(642) + m(643) + m(644) + m(645) + m(646) &
     &  + m(647) + m(648)
      p(1155) = m(649) + m(650) + m(651) + m(652) + m(653) + m(654) &
     &  + m(655) + m(656)
      p(1156) = p(3)*p(284) - p(1153)
      p(1157) = p(37)*p(54) - p(1154)
      p(1158) = p(38)*p(54) - p(1155)
      p(1159) = p(5)*p(284)
      p(1160) = p(40)*p(54)
      p(1161) = p(41)*p(54)
      p(1162) = p(42)*p(54)
      p(1163) = p(33)*p(55)
      p(1164) = p(34)*p(55)
      p(1165) = p(2)*p(285)
      p(1166) = p(7)*p(255)
      p(1167) = m(657) + m(658) + m(659) + m(660) + m(661) + m(662)&
     &  + m(663) + m(664)
      p(1168) = p(7)*p(256) - p(1167)
      p(1169) = p(7)*p(257)
      p(1170) = p(37)*p(55) - p(1167)
      p(1171) = p(7)*p(258) - p(1170)
      p(1172) = p(5)*p(285)
      p(1173) = p(40)*p(55)
      p(1174) = p(41)*p(55)
      p(1175) = p(42)*p(55)
      p(1176) = p(6)*p(271) - p(1117)
      p(1177) = p(1)*p(286) - p(1176)
      p(1178) = p(2)*p(286)
      p(1179) = p(6)*p(274) - p(1120)
      p(1180) = p(6)*p(275) - p(1121)
      p(1181) = p(6)*p(276) - p(1122)
      p(1182) = p(3)*p(286) - p(1179)
      p(1183) = p(6)*p(278) - p(1124)
      p(1184) = p(6)*p(279) - p(1125)
      p(1185) = p(5)*p(286)
      p(1186) = p(32)*p(57)
      p(1187) = p(41)*p(56)
      p(1188) = p(42)*p(56)
      p(1189) = p(43)*p(54)
      p(1190) = p(43)*p(55)
      p(1191) = p(1)*p(287)
      p(1192) = p(2)*p(287)
      p(1193) = p(44)*p(47) - p(960)
      p(1194) = p(44)*p(48) - p(961)
      p(1195) = p(3)*p(287) - p(1193)
      p(1196) = p(4)*p(287) - p(1194)
      p(1197) = p(5)*p(287)
      p(1198) = p(8)*p(199) - p(1055)
      p(1199) = p(8)*p(200) - p(1149)
      p(1200) = p(44)*p(54)
      p(1201) = p(44)*p(55)
      p(1202) = p(6)*p(287) - p(1198)
      p(1203) = p(10)*p(58)
      p(1204) = p(2)*p(288)
      p(1205) = p(1)*p(290)
      p(1206) = p(2)*p(290)
      p(1207) = p(14)*p(58)
      p(1208) = p(15)*p(58)
      p(1209) = p(16)*p(58)
      p(1210) = p(2)*p(291)
      p(1211) = p(18)*p(58)
      p(1212) = p(19)*p(58)
      p(1213) = p(20)*p(58)
      p(1214) = p(21)*p(58)
      p(1215) = p(22)*p(58)
      p(1216) = p(5)*p(288)
      p(1217) = p(2)*p(292)
      p(1218) = p(5)*p(290)
      p(1219) = p(5)*p(291)
      p(1220) = p(1)*p(293)
      p(1221) = p(2)*p(293)
      p(1222) = p(3)*p(293)
      p(1223) = p(4)*p(293)
      p(1224) = p(5)*p(293)
      p(1225) = m(665) + m(666) + m(667) + m(668)
      p(1226) = p(1)*p(294) - p(1225)
      p(1227) = p(2)*p(294)
      p(1228) = p(3)*p(294)
      p(1229) = m(669) + m(670) + m(671) + m(672) + m(673) + m(674) &
     &  + m(675) + m(676)
      p(1230) = p(4)*p(294) - p(1229)
      p(1231) = p(5)*p(294)
      p(1232) = m(677) + m(678) + m(679) + m(680)
      p(1233) = m(681) + m(682)
      p(1234) = p(1)*p(295)
      p(1235) = p(2)*p(295)
      p(1236) = m(683) + m(684) + m(685) + m(686)
      p(1237) = m(687) + m(688) + m(689) + m(690) + m(691) + m(692) &
     &  + m(693) + m(694)
      p(1238) = p(3)*p(295) - p(1236)
      p(1239) = p(4)*p(295) - p(1237)
      p(1240) = p(5)*p(295)
      p(1241) = m(695) + m(696) + m(697) + m(698)
      p(1242) = m(699) + m(700) + m(701) + m(702) + m(703) + m(704) &
     &  + m(705) + m(706)
      p(1243) = m(707)
      p(1244) = p(1)*p(296)
      p(1245) = p(2)*p(296)
      p(1246) = p(3)*p(296)
      p(1247) = p(4)*p(296)
      p(1248) = p(5)*p(296)
      p(1249) = p(32)*p(58)
      p(1250) = p(6)*p(294) - p(1232)
      p(1251) = p(6)*p(295) - p(1241)
      p(1252) = p(33)*p(58) - p(1225)
      p(1253) = p(1)*p(297) - p(1252)
      p(1254) = p(2)*p(297)
      p(1255) = p(3)*p(297)
      p(1256) = p(37)*p(58) - p(1229)
      p(1257) = p(4)*p(297) - p(1256)
      p(1258) = p(5)*p(297)
      p(1259) = p(7)*p(293) - p(1232)
      p(1260) = p(41)*p(58)
      p(1261) = p(42)*p(58)
      p(1262) = p(7)*p(295) - p(1242)
      p(1263) = p(6)*p(297) - p(1259)
      p(1264) = p(44)*p(58) - p(1233)
      p(1265) = p(2)*p(298)
      p(1266) = p(9)*p(77)
      p(1267) = p(2)*p(300)
      p(1268) = p(9)*p(79)
      p(1269) = p(2)*p(302)
      p(1270) = p(9)*p(81)
      p(1271) = p(2)*p(303)
      p(1272) = p(2)*p(304)
      p(1273) = p(9)*p(84)
      p(1274) = p(9)*p(85)
      p(1275) = p(2)*p(306)
      p(1276) = p(9)*p(87)
      p(1277) = p(2)*p(307)
      p(1278) = p(9)*p(89)
      p(1279) = p(9)*p(90)
      p(1280) = p(2)*p(308)
      p(1281) = p(9)*p(92)
      p(1282) = p(9)*p(93)
      p(1283) = p(2)*p(309)
      p(1284) = p(9)*p(95)
      p(1285) = p(9)*p(96)
      p(1286) = p(9)*p(97)
      p(1287) = p(9)*p(98)
      p(1288) = p(2)*p(310)
      p(1289) = p(9)*p(100)
      p(1290) = p(9)*p(101)
      p(1291) = p(9)*p(102)
      p(1292) = p(5)*p(298)
      p(1293) = p(2)*p(311)
      p(1294) = p(5)*p(300)
      p(1295) = p(2)*p(313)
      p(1296) = p(5)*p(302)
      p(1297) = p(5)*p(303)
      p(1298) = p(5)*p(304)
      p(1299) = p(2)*p(314)
      p(1300) = p(5)*p(306)
      p(1301) = p(5)*p(307)
      p(1302) = p(5)*p(308)
      p(1303) = p(5)*p(309)
      p(1304) = p(5)*p(310)
      p(1305) = p(9)*p(116)
      p(1306) = p(2)*p(315)
      p(1307) = p(9)*p(118)
      p(1308) = p(2)*p(317)
      p(1309) = p(9)*p(120)
      p(1310) = p(9)*p(121)
      p(1311) = p(9)*p(122)
      p(1312) = p(2)*p(318)
      p(1313) = p(9)*p(124)
      p(1314) = p(9)*p(125)
      p(1315) = p(9)*p(126)
      p(1316) = p(9)*p(127)
      p(1317) = p(9)*p(128)
      p(1318) = p(5)*p(315)
      p(1319) = p(2)*p(319)
      p(1320) = p(5)*p(317)
      p(1321) = p(5)*p(318)
      p(1322) = p(9)*p(133)
      p(1323) = p(2)*p(320)
      p(1324) = p(9)*p(135)
      p(1325) = p(9)*p(136)
      p(1326) = p(5)*p(320)
      p(1327) = p(9)*p(138)
      p(1328) = p(2)*p(321)
      p(1329) = p(2)*p(322)
      p(1330) = p(9)*p(141)
      p(1331) = p(9)*p(142)
      p(1332) = p(2)*p(324)
      p(1333) = p(9)*p(144)
      p(1334) = p(9)*p(145)
      p(1335) = p(9)*p(146)
      p(1336) = p(2)*p(325)
      p(1337) = p(9)*p(148)
      p(1338) = p(9)*p(149)
      p(1339) = p(9)*p(150)
      p(1340) = p(9)*p(151)
      p(1341) = p(9)*p(152)
      p(1342) = p(2)*p(326)
      p(1343) = p(9)*p(154)
      p(1344) = p(9)*p(155)
      p(1345) = p(9)*p(156)
      p(1346) = p(9)*p(157)
      p(1347) = p(9)*p(158)
      p(1348) = p(5)*p(321)
      p(1349) = p(5)*p(322)
      p(1350) = p(2)*p(327)
      p(1351) = p(5)*p(324)
      p(1352) = p(5)*p(325)
      p(1353) = p(5)*p(326)
      p(1354) = p(9)*p(165)
      p(1355) = p(9)*p(166)
      p(1356) = p(2)*p(328)
      p(1357) = p(9)*p(168)
      p(1358) = p(9)*p(169)
      p(1359) = p(9)*p(170)
      p(1360) = p(5)*p(328)
      p(1361) = p(9)*p(172)
      p(1362) = p(2)*p(329)
      p(1363) = p(9)*p(174)
      p(1364) = p(9)*p(175)
      p(1365) = p(5)*p(329)
      p(1366) = p(9)*p(177)
      p(1367) = p(9)*p(178)
      p(1368) = p(2)*p(330)
      p(1369) = p(9)*p(180)
      p(1370) = p(9)*p(181)
      p(1371) = p(9)*p(182)
      p(1372) = p(5)*p(330)
      p(1373) = p(9)*p(184)
      p(1374) = p(9)*p(185)
      p(1375) = p(2)*p(331)
      p(1376) = p(9)*p(187)
      p(1377) = p(9)*p(188)
      p(1378) = p(9)*p(189)
      p(1379) = p(5)*p(331)
      p(1380) = p(9)*p(191)
      p(1381) = p(9)*p(192)
      p(1382) = p(9)*p(193)
      p(1383) = p(9)*p(194)
      p(1384) = p(2)*p(332)
      p(1385) = p(9)*p(196)
      p(1386) = p(9)*p(197)
      p(1387) = p(5)*p(332)
      p(1388) = p(9)*p(199)
      p(1389) = p(9)*p(200)
      p(1390) = p(9)*p(201)
      p(1391) = p(9)*p(202)
      p(1392) = p(2)*p(333)
      p(1393) = p(9)*p(204)
      p(1394) = p(2)*p(335)
      p(1395) = p(9)*p(206)
      p(1396) = p(9)*p(207)
      p(1397) = p(2)*p(336)
      p(1398) = p(9)*p(209)
      p(1399) = p(9)*p(210)
      p(1400) = p(9)*p(211)
      p(1401) = p(2)*p(337)
      p(1402) = p(9)*p(213)
      p(1403) = p(9)*p(214)
      p(1404) = p(9)*p(215)
      p(1405) = p(9)*p(216)
      p(1406) = p(2)*p(338)
      p(1407) = p(9)*p(218)
      p(1408) = p(9)*p(219)
      p(1409) = p(9)*p(220)
      p(1410) = p(9)*p(221)
      p(1411) = p(9)*p(222)
      p(1412) = p(5)*p(333)
      p(1413) = p(2)*p(339)
      p(1414) = p(5)*p(335)
      p(1415) = p(5)*p(336)
      p(1416) = p(5)*p(337)
      p(1417) = p(5)*p(338)
      p(1418) = p(9)*p(229)
      p(1419) = p(2)*p(340)
      p(1420) = p(9)*p(231)
      p(1421) = p(9)*p(232)
      p(1422) = p(9)*p(233)
      p(1423) = p(9)*p(234)
      p(1424) = p(5)*p(340)
      p(1425) = p(9)*p(236)
      p(1426) = p(9)*p(237)
      p(1427) = p(2)*p(341)
      p(1428) = p(9)*p(239)
      p(1429) = p(9)*p(240)
      p(1430) = p(9)*p(241)
      p(1431) = p(9)*p(242)
      p(1432) = p(9)*p(243)
      p(1433) = p(9)*p(244)
      p(1434) = p(5)*p(341)
      p(1435) = p(9)*p(246)
      p(1436) = p(9)*p(247)
      p(1437) = p(9)*p(248)
      p(1438) = p(2)*p(342)
      p(1439) = p(9)*p(250)
      p(1440) = p(9)*p(251)
      p(1441) = p(5)*p(342)
      p(1442) = p(9)*p(253)
      p(1443) = p(2)*p(343)
      p(1444) = p(9)*p(255)
      p(1445) = p(9)*p(256)
      p(1446) = p(9)*p(257)
      p(1447) = p(9)*p(258)
      p(1448) = p(5)*p(343)
      p(1449) = p(9)*p(260)
      p(1450) = p(2)*p(344)
      p(1451) = p(9)*p(262)
      p(1452) = p(9)*p(263)
      p(1453) = p(9)*p(264)
      p(1454) = p(9)*p(265)
      p(1455) = p(5)*p(344)
      p(1456) = p(9)*p(267)
      p(1457) = p(9)*p(268)
      p(1458) = p(9)*p(269)
      p(1459) = p(9)*p(270)
      p(1460) = p(9)*p(271)
      p(1461) = p(9)*p(272)
      p(1462) = p(2)*p(345)
      p(1463) = p(9)*p(274)
      p(1464) = p(9)*p(275)
      p(1465) = p(9)*p(276)
      p(1466) = p(9)*p(277)
      p(1467) = p(9)*p(278)
      p(1468) = p(9)*p(279)
      p(1469) = p(5)*p(345)
      p(1470) = p(9)*p(281)
      p(1471) = p(9)*p(282)
      p(1472) = p(9)*p(283)
      p(1473) = p(9)*p(284)
      p(1474) = p(9)*p(285)
      p(1475) = p(9)*p(286)
      p(1476) = p(9)*p(287)
      p(1477) = p(9)*p(288)
      p(1478) = p(2)*p(346)
      p(1479) = p(9)*p(290)
      p(1480) = p(9)*p(291)
      p(1481) = p(5)*p(346)
      p(1482) = p(9)*p(293)
      p(1483) = p(9)*p(294)
      p(1484) = p(9)*p(295)
      p(1485) = p(9)*p(296)
      p(1486) = p(9)*p(297)
      p(1487) = p(2)*p(347)
      p(1488) = p(2)*p(76)
      p(1489) = p(10)*p(12)
      p(1490) = p(2)*p(350)
      p(1491) = p(2)*p(78)
      p(1492) = p(14)*p(67)
      p(1493) = p(2)*p(80)
      p(1494) = p(10)*p(69)
      p(1495) = p(2)*p(352)
      p(1496) = p(14)*p(12)
      p(1497) = p(2)*p(354)
      p(1498) = p(10)*p(15)
      p(1499) = p(10)*p(16)
      p(1500) = p(2)*p(355)
      p(1501) = p(2)*p(356)
      p(1502) = p(2)*p(82)
      p(1503) = p(2)*p(83)
      p(1504) = p(1)*p(84) - p(462)
      p(1505) = p(1)*p(85) - p(462)
      p(1506) = p(2)*p(86)
      p(1507) = p(3)*p(84) - p(473)
      p(1508) = p(1)*p(358) - p(1507)
      p(1509) = p(2)*p(358)
      p(1510) = p(19)*p(67)
      p(1511) = p(2)*p(88)
      p(1512) = p(1)*p(89) - p(467)
      p(1513) = p(1)*p(90) - p(467)
      p(1514) = p(2)*p(91)
      p(1515) = p(1)*p(92) - p(470)
      p(1516) = p(1)*p(93) - p(470)
      p(1517) = p(2)*p(94)
      p(1518) = p(14)*p(18)
      p(1519) = p(3)*p(92) - p(473)
      p(1520) = p(1)*p(359) - p(1519)
      p(1521) = p(2)*p(359)
      p(1522) = p(14)*p(21)
      p(1523) = p(19)*p(69)
      p(1524) = p(20)*p(69)
      p(1525) = p(22)*p(67)
      p(1526) = p(2)*p(99)
      p(1527) = p(3)*p(100) - p(495)
      p(1528) = p(3)*p(102) - p(495)
      p(1529) = p(10)*p(70)
      p(1530) = p(2)*p(360)
      p(1531) = p(2)*p(361)
      p(1532) = p(4)*p(84) - p(486) - p(480) - p(477)
      p(1533) = p(1)*p(363) - p(1532)
      p(1534) = p(2)*p(363)
      p(1535) = p(15)*p(19) - p(488)
      p(1536) = p(1)*p(364) - p(1535)
      p(1537) = p(2)*p(364)
      p(1538) = p(18)*p(19) - p(491)
      p(1539) = p(4)*p(89) - p(488)
      p(1540) = p(1)*p(365) - p(1539)
      p(1541) = p(2)*p(365)
      p(1542) = p(18)*p(20) - p(491)
      p(1543) = p(19)*p(20)
      p(1544) = p(3)*p(360) - p(1532)
      p(1545) = p(1)*p(366) - p(1544)
      p(1546) = p(2)*p(366)
      p(1547) = p(14)*p(70)
      p(1548) = p(3)*p(364) - p(1538)
      p(1549) = p(3)*p(365) - p(1542)
      p(1550) = p(15)*p(22) - p(488)
      p(1551) = p(1)*p(367) - p(1550)
      p(1552) = p(2)*p(367)
      p(1553) = p(4)*p(100) - p(491)
      p(1554) = p(19)*p(22)
      p(1555) = p(20)*p(22)
      p(1556) = p(3)*p(367) - p(1553)
      p(1557) = p(5)*p(347)
      p(1558) = p(2)*p(368)
      p(1559) = p(2)*p(104)
      p(1560) = p(5)*p(350)
      p(1561) = p(2)*p(106)
      p(1562) = p(5)*p(352)
      p(1563) = p(2)*p(370)
      p(1564) = p(5)*p(354)
      p(1565) = p(5)*p(355)
      p(1566) = p(5)*p(356)
      p(1567) = p(2)*p(110)
      p(1568) = p(5)*p(358)
      p(1569) = p(5)*p(359)
      p(1570) = p(5)*p(360)
      p(1571) = p(5)*p(361)
      p(1572) = p(2)*p(371)
      p(1573) = p(5)*p(363)
      p(1574) = p(5)*p(364)
      p(1575) = p(5)*p(365)
      p(1576) = p(5)*p(366)
      p(1577) = p(5)*p(367)
      p(1578) = p(5)*p(103)
      p(1579) = p(2)*p(372)
      p(1580) = p(5)*p(105)
      p(1581) = p(2)*p(374)
      p(1582) = p(5)*p(107)
      p(1583) = p(5)*p(108)
      p(1584) = p(5)*p(109)
      p(1585) = p(2)*p(375)
      p(1586) = p(5)*p(111)
      p(1587) = p(5)*p(112)
      p(1588) = p(5)*p(113)
      p(1589) = p(5)*p(114)
      p(1590) = p(5)*p(115)
      p(1591) = p(10)*p(27)
      p(1592) = p(2)*p(376)
      p(1593) = p(2)*p(117)
      p(1594) = p(3)*p(376)
      p(1595) = p(2)*p(119)
      p(1596) = p(1)*p(378)
      p(1597) = p(2)*p(378)
      p(1598) = p(14)*p(29)
      p(1599) = p(6)*p(355)
      p(1600) = p(6)*p(356)
      p(1601) = p(2)*p(123)
      p(1602) = p(6)*p(358)
      p(1603) = p(6)*p(359)
      p(1604) = p(6)*p(360)
      p(1605) = p(6)*p(361)
      p(1606) = p(2)*p(379)
      p(1607) = p(6)*p(363)
      p(1608) = p(6)*p(364)
      p(1609) = p(6)*p(365)
      p(1610) = p(6)*p(366)
      p(1611) = p(6)*p(367)
      p(1612) = p(5)*p(376)
      p(1613) = p(2)*p(130)
      p(1614) = p(5)*p(378)
      p(1615) = p(5)*p(379)
      p(1616) = p(5)*p(129)
      p(1617) = p(2)*p(380)
      p(1618) = p(5)*p(131)
      p(1619) = p(5)*p(132)
      p(1620) = p(32)*p(67)
      p(1621) = p(2)*p(134)
      p(1622) = p(32)*p(69)
      p(1623) = p(32)*p(70)
      p(1624) = p(5)*p(137)
      p(1625) = p(10)*p(72)
      p(1626) = p(2)*p(381)
      p(1627) = p(1)*p(383)
      p(1628) = p(2)*p(383)
      p(1629) = p(14)*p(72)
      p(1630) = p(15)*p(72)
      p(1631) = p(16)*p(72)
      p(1632) = p(2)*p(384)
      p(1633) = p(18)*p(72)
      p(1634) = p(19)*p(72)
      p(1635) = p(20)*p(72)
      p(1636) = p(21)*p(72)
      p(1637) = p(22)*p(72)
      p(1638) = p(5)*p(381)
      p(1639) = p(2)*p(385)
      p(1640) = p(5)*p(383)
      p(1641) = p(5)*p(384)
      p(1642) = p(32)*p(27)
      p(1643) = p(2)*p(386)
      p(1644) = p(32)*p(29)
      p(1645) = p(32)*p(30)
      p(1646) = p(5)*p(386)
      p(1647) = p(10)*p(33)
      p(1648) = p(10)*p(34)
      p(1649) = p(2)*p(387)
      p(1650) = p(2)*p(388)
      p(1651) = p(2)*p(139)
      p(1652) = p(2)*p(140)
      p(1653) = p(3)*p(387)
      p(1654) = p(3)*p(388)
      p(1655) = p(2)*p(143)
      p(1656) = p(33)*p(69)
      p(1657) = p(34)*p(69)
      p(1658) = p(2)*p(390)
      p(1659) = p(14)*p(36)
      p(1660) = p(1)*p(145) - p(588)
      p(1661) = p(1)*p(146) - p(588)
      p(1662) = p(2)*p(147)
      p(1663) = p(3)*p(148) - p(600)
      p(1664) = p(3)*p(150) - p(600)
      p(1665) = p(4)*p(145) - p(621) - p(608) - p(594) - p(594)
      p(1666) = p(1)*p(391) - p(1665)
      p(1667) = p(2)*p(391)
      p(1668) = p(4)*p(148) - p(624) - p(619) - p(601)
      p(1669) = p(4)*p(149) - p(625)
      p(1670) = p(3)*p(391) - p(1668)
      p(1671) = p(1)*p(151) - p(602)
      p(1672) = p(1)*p(152) - p(602)
      p(1673) = p(2)*p(153)
      p(1674) = p(3)*p(154) - p(618)
      p(1675) = p(19)*p(37) - p(625)
      p(1676) = p(3)*p(157) - p(618)
      p(1677) = p(22)*p(37) - p(625)
      p(1678) = p(7)*p(360) - p(1666)
      p(1679) = p(1)*p(392) - p(1678)
      p(1680) = p(2)*p(392)
      p(1681) = p(7)*p(363) - p(1668)
      p(1682) = p(7)*p(364) - p(1675)
      p(1683) = p(4)*p(156) - p(626)
      p(1684) = p(3)*p(392) - p(1681)
      p(1685) = p(7)*p(367) - p(1677)
      p(1686) = p(5)*p(387)
      p(1687) = p(5)*p(388)
      p(1688) = p(2)*p(161)
      p(1689) = p(5)*p(390)
      p(1690) = p(5)*p(391)
      p(1691) = p(5)*p(392)
      p(1692) = p(5)*p(159)
      p(1693) = p(5)*p(160)
      p(1694) = p(2)*p(393)
      p(1695) = p(5)*p(162)
      p(1696) = p(5)*p(163)
      p(1697) = p(5)*p(164)
      p(1698) = p(1)*p(165) - p(649)
      p(1699) = p(1)*p(166) - p(649)
      p(1700) = p(2)*p(167)
      p(1701) = p(40)*p(69)
      p(1702) = p(4)*p(169) - p(669) - p(666) - p(660) - p(660)
      p(1703) = p(40)*p(70) - p(1702)
      p(1704) = p(5)*p(171)
      p(1705) = p(6)*p(165) - p(747)
      p(1706) = p(1)*p(394) - p(1705)
      p(1707) = p(2)*p(394)
      p(1708) = p(3)*p(394)
      p(1709) = p(6)*p(169) - p(751)
      p(1710) = p(4)*p(394) - p(1709)
      p(1711) = p(5)*p(394)
      p(1712) = p(41)*p(67)
      p(1713) = p(2)*p(173)
      p(1714) = p(41)*p(69)
      p(1715) = p(41)*p(70)
      p(1716) = p(5)*p(176)
      p(1717) = p(1)*p(177) - p(693)
      p(1718) = p(1)*p(178) - p(693)
      p(1719) = p(2)*p(179)
      p(1720) = p(42)*p(69)
      p(1721) = p(4)*p(181) - p(713) - p(710) - p(704) - p(704)
      p(1722) = p(42)*p(70) - p(1721)
      p(1723) = p(5)*p(183)
      p(1724) = p(1)*p(184) - p(720)
      p(1725) = p(1)*p(185) - p(720)
      p(1726) = p(2)*p(186)
      p(1727) = p(43)*p(69)
      p(1728) = p(6)*p(391) - p(1702)
      p(1729) = p(6)*p(392) - p(1703)
      p(1730) = p(5)*p(190)
      p(1731) = p(32)*p(40)
      p(1732) = p(6)*p(184) - p(747)
      p(1733) = p(1)*p(395) - p(1732)
      p(1734) = p(2)*p(395)
      p(1735) = p(3)*p(395)
      p(1736) = p(6)*p(188) - p(751)
      p(1737) = p(4)*p(395) - p(1736)
      p(1738) = p(5)*p(395)
      p(1739) = p(32)*p(43)
      p(1740) = p(41)*p(72)
      p(1741) = p(42)*p(72)
      p(1742) = p(44)*p(67)
      p(1743) = p(2)*p(195)
      p(1744) = p(44)*p(69)
      p(1745) = p(44)*p(70)
      p(1746) = p(5)*p(198)
      p(1747) = p(6)*p(199) - p(806)
      p(1748) = p(6)*p(201) - p(806)
      p(1749) = p(10)*p(73)
      p(1750) = p(2)*p(396)
      p(1751) = p(2)*p(397)
      p(1752) = p(3)*p(396)
      p(1753) = p(3)*p(397)
      p(1754) = p(2)*p(399)
      p(1755) = p(14)*p(73)
      p(1756) = p(7)*p(145) - p(776) - p(700) - p(682) - p(700)
      p(1757) = p(1)*p(400) - p(1756)
      p(1758) = p(2)*p(400)
      p(1759) = p(7)*p(148) - p(778) - p(703) - p(684) - p(703)
      p(1760) = p(7)*p(149) - p(780) - p(704) - p(686) - p(704)
      p(1761) = p(3)*p(400) - p(1759)
      p(1762) = p(4)*p(396) - p(1756)
      p(1763) = p(1)*p(401) - p(1762)
      p(1764) = p(2)*p(401)
      p(1765) = p(18)*p(73) - p(1759)
      p(1766) = p(19)*p(73)
      p(1767) = p(20)*p(73) - p(1760)
      p(1768) = p(3)*p(401) - p(1765)
      p(1769) = p(22)*p(73)
      p(1770) = p(5)*p(396)
      p(1771) = p(5)*p(397)
      p(1772) = p(2)*p(402)
      p(1773) = p(5)*p(399)
      p(1774) = p(5)*p(400)
      p(1775) = p(5)*p(401)
      p(1776) = p(7)*p(165) - p(787) - p(762) - p(755)
      p(1777) = p(1)*p(403) - p(1776)
      p(1778) = p(2)*p(403)
      p(1779) = p(3)*p(403)
      p(1780) = p(7)*p(169) - p(790) - p(766) - p(759)
      p(1781) = p(4)*p(403) - p(1780)
      p(1782) = p(5)*p(403)
      p(1783) = p(33)*p(41) - p(792)
      p(1784) = p(1)*p(404) - p(1783)
      p(1785) = p(2)*p(404)
      p(1786) = p(3)*p(404)
      p(1787) = p(37)*p(41) - p(796)
      p(1788) = p(4)*p(404) - p(1787)
      p(1789) = p(5)*p(404)
      p(1790) = p(40)*p(41) - p(799)
      p(1791) = p(7)*p(177) - p(792)
      p(1792) = p(1)*p(405) - p(1791)
      p(1793) = p(2)*p(405)
      p(1794) = p(3)*p(405)
      p(1795) = p(7)*p(181) - p(796)
      p(1796) = p(4)*p(405) - p(1795)
      p(1797) = p(5)*p(405)
      p(1798) = p(40)*p(42) - p(799)
      p(1799) = p(41)*p(42)
      p(1800) = p(6)*p(396) - p(1776)
      p(1801) = p(1)*p(406) - p(1800)
      p(1802) = p(2)*p(406)
      p(1803) = p(3)*p(406)
      p(1804) = p(6)*p(400) - p(1780)
      p(1805) = p(4)*p(406) - p(1804)
      p(1806) = p(5)*p(406)
      p(1807) = p(32)*p(73)
      p(1808) = p(6)*p(404) - p(1790)
      p(1809) = p(6)*p(405) - p(1798)
      p(1810) = p(33)*p(44) - p(792)
      p(1811) = p(1)*p(407) - p(1810)
      p(1812) = p(2)*p(407)
      p(1813) = p(3)*p(407)
      p(1814) = p(37)*p(44) - p(796)
      p(1815) = p(4)*p(407) - p(1814)
      p(1816) = p(5)*p(407)
      p(1817) = p(7)*p(199) - p(799)
      p(1818) = p(41)*p(44)
      p(1819) = p(42)*p(44)
      p(1820) = p(6)*p(407) - p(1817)
      p(1821) = p(10)*p(45)
      p(1822) = p(2)*p(408)
      p(1823) = p(2)*p(203)
      p(1824) = p(47)*p(67)
      p(1825) = p(2)*p(205)
      p(1826) = p(1)*p(410)
      p(1827) = p(2)*p(410)
      p(1828) = p(1)*p(206) - p(811)
      p(1829) = p(1)*p(207) - p(811)
      p(1830) = p(2)*p(208)
      p(1831) = p(3)*p(209) - p(827)
      p(1832) = p(4)*p(206) - p(839) - p(836) - p(817)
      p(1833) = p(1)*p(411) - p(1832)
      p(1834) = p(2)*p(411)
      p(1835) = p(4)*p(209) - p(842) - p(838) - p(819) - p(819)
      p(1836) = p(4)*p(210) - p(843)
      p(1837) = p(49)*p(67)
      p(1838) = p(2)*p(212)
      p(1839) = p(14)*p(47)
      p(1840) = p(3)*p(411) - p(1835)
      p(1841) = p(1)*p(412)
      p(1842) = p(2)*p(412)
      p(1843) = p(14)*p(49)
      p(1844) = p(3)*p(214) - p(827)
      p(1845) = p(1)*p(215) - p(829)
      p(1846) = p(1)*p(216) - p(829)
      p(1847) = p(2)*p(217)
      p(1848) = p(3)*p(218) - p(847)
      p(1849) = p(19)*p(48) - p(843)
      p(1850) = p(20)*p(48) - p(843)
      p(1851) = p(3)*p(221) - p(847)
      p(1852) = p(8)*p(360) - p(1832)
      p(1853) = p(1)*p(413) - p(1852)
      p(1854) = p(2)*p(413)
      p(1855) = p(8)*p(363) - p(1840)
      p(1856) = p(8)*p(364) - p(1849)
      p(1857) = p(8)*p(365) - p(1850)
      p(1858) = p(3)*p(413) - p(1855)
      p(1859) = p(4)*p(222) - p(853)
      p(1860) = p(5)*p(408)
      p(1861) = p(2)*p(224)
      p(1862) = p(5)*p(410)
      p(1863) = p(5)*p(411)
      p(1864) = p(5)*p(412)
      p(1865) = p(5)*p(413)
      p(1866) = p(5)*p(223)
      p(1867) = p(2)*p(414)
      p(1868) = p(5)*p(225)
      p(1869) = p(5)*p(226)
      p(1870) = p(5)*p(227)
      p(1871) = p(5)*p(228)
      p(1872) = p(52)*p(67)
      p(1873) = p(2)*p(230)
      p(1874) = p(3)*p(231) - p(887)
      p(1875) = p(4)*p(232) - p(894) - p(893) - p(884) - p(884)
      p(1876) = p(3)*p(233) - p(887)
      p(1877) = p(52)*p(70) - p(1875)
      p(1878) = p(5)*p(235)
      p(1879) = p(1)*p(415)
      p(1880) = p(2)*p(415)
      p(1881) = p(6)*p(231) - p(1039)
      p(1882) = p(6)*p(232) - p(1040)
      p(1883) = p(3)*p(415) - p(1881)
      p(1884) = p(4)*p(415) - p(1882)
      p(1885) = p(5)*p(415)
      p(1886) = p(1)*p(236) - p(903)
      p(1887) = p(1)*p(237) - p(903)
      p(1888) = p(2)*p(238)
      p(1889) = p(3)*p(239) - p(921)
      p(1890) = p(4)*p(240) - p(935) - p(928) - p(917)
      p(1891) = p(4)*p(241) - p(936) - p(929) - p(917)
      p(1892) = p(3)*p(242) - p(921)
      p(1893) = p(4)*p(243) - p(938) - p(929) - p(928)
      p(1894) = p(4)*p(244) - p(938) - p(936) - p(935)
      p(1895) = p(5)*p(245)
      p(1896) = p(6)*p(246) - p(1054)
      p(1897) = p(7)*p(236) - p(1138) - p(1128) - p(958)
      p(1898) = p(1)*p(416) - p(1897)
      p(1899) = p(2)*p(416)
      p(1900) = p(7)*p(239) - p(1141) - p(1130) - p(960) - p(960)
      p(1901) = p(7)*p(240) - p(1142) - p(1132) - p(961)
      p(1902) = p(7)*p(241) - p(1143) - p(1131) - p(961)
      p(1903) = p(3)*p(416) - p(1900)
      p(1904) = p(7)*p(243) - p(1145) - p(1135) - p(963)
      p(1905) = p(4)*p(416) - p(1904) - p(1902) - p(1901)
      p(1906) = p(5)*p(416)
      p(1907) = p(7)*p(246) - p(1148) - p(1137) - p(965) - p(965)
      p(1908) = p(7)*p(247) - p(1149)
      p(1909) = p(54)*p(67)
      p(1910) = p(2)*p(249)
      p(1911) = p(54)*p(69)
      p(1912) = p(54)*p(70)
      p(1913) = p(5)*p(252)
      p(1914) = p(55)*p(67)
      p(1915) = p(2)*p(254)
      p(1916) = p(3)*p(255) - p(994)
      p(1917) = p(4)*p(256) - p(1001) - p(1000) - p(991) - p(991)
      p(1918) = p(3)*p(257) - p(994)
      p(1919) = p(55)*p(70) - p(1917)
      p(1920) = p(5)*p(259)
      p(1921) = p(56)*p(67)
      p(1922) = p(2)*p(261)
      p(1923) = p(3)*p(262) - p(1021)
      p(1924) = p(6)*p(411) - p(1875)
      p(1925) = p(3)*p(264) - p(1021)
      p(1926) = p(6)*p(413) - p(1877)
      p(1927) = p(5)*p(266)
      p(1928) = p(32)*p(52)
      p(1929) = p(6)*p(416) - p(1907)
      p(1930) = p(1)*p(417)
      p(1931) = p(2)*p(417)
      p(1932) = p(6)*p(262) - p(1039)
      p(1933) = p(6)*p(263) - p(1040)
      p(1934) = p(3)*p(417) - p(1932)
      p(1935) = p(4)*p(417) - p(1933)
      p(1936) = p(5)*p(417)
      p(1937) = p(32)*p(56)
      p(1938) = p(6)*p(268) - p(1054)
      p(1939) = p(54)*p(72)
      p(1940) = p(55)*p(72)
      p(1941) = p(1)*p(271) - p(1072)
      p(1942) = p(1)*p(272) - p(1072)
      p(1943) = p(2)*p(273)
      p(1944) = p(3)*p(274) - p(1090)
      p(1945) = p(4)*p(275) - p(1104) - p(1097) - p(1086)
      p(1946) = p(4)*p(276) - p(1105) - p(1098) - p(1086)
      p(1947) = p(3)*p(277) - p(1090)
      p(1948) = p(4)*p(278) - p(1107) - p(1098) - p(1097)
      p(1949) = p(4)*p(279) - p(1107) - p(1105) - p(1104)
      p(1950) = p(5)*p(280)
      p(1951) = p(6)*p(281) - p(1186)
      p(1952) = p(41)*p(53) - p(1149)
      p(1953) = p(42)*p(53) - p(1149)
      p(1954) = p(6)*p(286) - p(1186)
      p(1955) = p(8)*p(396) - p(1897)
      p(1956) = p(1)*p(418) - p(1955)
      p(1957) = p(2)*p(418)
      p(1958) = p(47)*p(73) - p(1900)
      p(1959) = p(7)*p(275) - p(1194) - p(1142) - p(1131)
      p(1960) = p(7)*p(276) - p(1194) - p(1143) - p(1132)
      p(1961) = p(3)*p(418) - p(1958)
      p(1962) = p(7)*p(278) - p(1196) - p(1145) - p(1134)
      p(1963) = p(4)*p(418) - p(1962) - p(1960) - p(1959)
      p(1964) = p(5)*p(418)
      p(1965) = p(8)*p(403) - p(1929)
      p(1966) = p(8)*p(404) - p(1952)
      p(1967) = p(8)*p(405) - p(1953)
      p(1968) = p(54)*p(73)
      p(1969) = p(55)*p(73)
      p(1970) = p(6)*p(418) - p(1965)
      p(1971) = p(7)*p(287) - p(1199)
      p(1972) = p(58)*p(67)
      p(1973) = p(2)*p(289)
      p(1974) = p(58)*p(69)
      p(1975) = p(58)*p(70)
      p(1976) = p(5)*p(292)
      p(1977) = p(6)*p(293) - p(1249)
      p(1978) = p(7)*p(294) - p(1261) - p(1260) - p(1233) - p(1233)
      p(1979) = p(6)*p(296) - p(1249)
      p(1980) = p(58)*p(73) - p(1978)
      p(1981) = p(10)*p(74)
      p(1982) = p(2)*p(419)
      p(1983) = p(1)*p(421)
      p(1984) = p(2)*p(421)
      p(1985) = p(8)*p(206) - p(1208) - p(987) - p(971) - p(987)
      p(1986) = p(1)*p(422) - p(1985)
      p(1987) = p(2)*p(422)
      p(1988) = p(8)*p(209) - p(1214) - p(990) - p(977) - p(990)
      p(1989) = p(8)*p(210) - p(1215) - p(991) - p(978) - p(991)
      p(1990) = p(1)*p(423)
      p(1991) = p(2)*p(423)
      p(1992) = p(14)*p(74)
      p(1993) = p(3)*p(422) - p(1988)
      p(1994) = p(15)*p(74) - p(1985)
      p(1995) = p(1)*p(424) - p(1994)
      p(1996) = p(2)*p(424)
      p(1997) = p(4)*p(421) - p(1988)
      p(1998) = p(19)*p(74)
      p(1999) = p(20)*p(74)
      p(2000) = p(3)*p(424) - p(1997)
      p(2001) = p(22)*p(74) - p(1989)
      p(2002) = p(5)*p(419)
      p(2003) = p(2)*p(425)
      p(2004) = p(5)*p(421)
      p(2005) = p(5)*p(422)
      p(2006) = p(5)*p(423)
      p(2007) = p(5)*p(424)
      p(2008) = p(1)*p(426)
      p(2009) = p(2)*p(426)
      p(2010) = p(8)*p(231) - p(1222) - p(1066) - p(1060)
      p(2011) = p(8)*p(232) - p(1223) - p(1067) - p(1061)
      p(2012) = p(3)*p(426) - p(2010)
      p(2013) = p(4)*p(426) - p(2011)
      p(2014) = p(5)*p(426)
      p(2015) = p(8)*p(236) - p(1225) - p(1163) - p(1150) - p(1225)
      p(2016) = p(1)*p(427) - p(2015)
      p(2017) = p(2)*p(427)
      p(2018) = p(8)*p(239) - p(1228) - p(1166) - p(1156)
      p(2019) = p(8)*p(240) - p(1229) - p(1167) - p(1157)
      p(2020) = p(8)*p(241) - p(1230) - p(1168) - p(1158)
      p(2021) = p(3)*p(427) - p(2018)
      p(2022) = p(8)*p(243) - p(1229) - p(1170) - p(1154)
      p(2023) = p(4)*p(427) - p(2022) - p(2020) - p(2019)
      p(2024) = p(5)*p(427)
      p(2025) = p(8)*p(246) - p(1232) - p(1190) - p(1189) - p(1232)
      p(2026) = p(8)*p(247) - p(1233) - p(1201) - p(1200) - p(1233)
      p(2027) = p(1)*p(428)
      p(2028) = p(2)*p(428)
      p(2029) = p(47)*p(54) - p(1236)
      p(2030) = p(48)*p(54) - p(1237)
      p(2031) = p(3)*p(428) - p(2029)
      p(2032) = p(4)*p(428) - p(2030)
      p(2033) = p(5)*p(428)
      p(2034) = p(52)*p(54) - p(1241)
      p(2035) = p(53)*p(54) - p(1242)
      p(2036) = p(1)*p(429)
      p(2037) = p(2)*p(429)
      p(2038) = p(8)*p(255) - p(1236)
      p(2039) = p(8)*p(256) - p(1237)
      p(2040) = p(3)*p(429) - p(2038)
      p(2041) = p(4)*p(429) - p(2039)
      p(2042) = p(5)*p(429)
      p(2043) = p(52)*p(55) - p(1241)
      p(2044) = p(53)*p(55) - p(1242)
      p(2045) = p(54)*p(55)
      p(2046) = p(1)*p(430)
      p(2047) = p(2)*p(430)
      p(2048) = p(6)*p(421) - p(2010)
      p(2049) = p(6)*p(422) - p(2011)
      p(2050) = p(3)*p(430) - p(2048)
      p(2051) = p(4)*p(430) - p(2049)
      p(2052) = p(5)*p(430)
      p(2053) = p(32)*p(74)
      p(2054) = p(6)*p(427) - p(2025)
      p(2055) = p(6)*p(428) - p(2034)
      p(2056) = p(6)*p(429) - p(2043)
      p(2057) = p(33)*p(74) - p(2015)
      p(2058) = p(1)*p(431) - p(2057)
      p(2059) = p(2)*p(431)
      p(2060) = p(7)*p(421) - p(2018)
      p(2061) = p(8)*p(275) - p(1256) - p(1167) - p(1154)
      p(2062) = p(7)*p(422) - p(2061) - p(2020) - p(2019)
      p(2063) = p(3)*p(431) - p(2060)
      p(2064) = p(8)*p(278) - p(1256) - p(1170) - p(1157)
      p(2065) = p(4)*p(431) - p(2064) - p(2062) - p(2061)
      p(2066) = p(5)*p(431)
      p(2067) = p(7)*p(426) - p(2025)
      p(2068) = p(41)*p(74)
      p(2069) = p(42)*p(74)
      p(2070) = p(7)*p(428) - p(2035)
      p(2071) = p(7)*p(429) - p(2044)
      p(2072) = p(6)*p(431) - p(2067)
      p(2073) = p(44)*p(74) - p(2026)
      p(2074) = p(1)*p(432)
      p(2075) = p(2)*p(432)
      p(2076) = p(47)*p(58) - p(1236)
      p(2077) = p(48)*p(58) - p(1237)
      p(2078) = p(3)*p(432) - p(2076)
      p(2079) = p(4)*p(432) - p(2077)
      p(2080) = p(5)*p(432)
      p(2081) = p(8)*p(293) - p(1241)
      p(2082) = p(8)*p(294) - p(1242)
      p(2083) = p(54)*p(58)
      p(2084) = p(55)*p(58)
      p(2085) = p(6)*p(432) - p(2081)
      p(2086) = p(7)*p(432) - p(2082)
      p(2087) = p(9)*p(347)
      p(2088) = p(2)*p(433)
      p(2089) = p(2)*p(299)
      p(2090) = p(9)*p(350)
      p(2091) = p(2)*p(301)
      p(2092) = p(9)*p(352)
      p(2093) = p(2)*p(435)
      p(2094) = p(9)*p(354)
      p(2095) = p(9)*p(355)
      p(2096) = p(9)*p(356)
      p(2097) = p(2)*p(305)
      p(2098) = p(9)*p(358)
      p(2099) = p(9)*p(359)
      p(2100) = p(9)*p(360)
      p(2101) = p(9)*p(361)
      p(2102) = p(2)*p(436)
      p(2103) = p(9)*p(363)
      p(2104) = p(9)*p(364)
      p(2105) = p(9)*p(365)
      p(2106) = p(9)*p(366)
      p(2107) = p(9)*p(367)
      p(2108) = p(5)*p(433)
      p(2109) = p(2)*p(312)
      p(2110) = p(5)*p(435)
      p(2111) = p(5)*p(436)
      p(2112) = p(5)*p(311)
      p(2113) = p(2)*p(437)
      p(2114) = p(5)*p(313)
      p(2115) = p(5)*p(314)
      p(2116) = p(9)*p(376)
      p(2117) = p(2)*p(316)
      p(2118) = p(9)*p(378)
      p(2119) = p(9)*p(379)
      p(2120) = p(5)*p(319)
      p(2121) = p(9)*p(381)
      p(2122) = p(2)*p(438)
      p(2123) = p(9)*p(383)
      p(2124) = p(9)*p(384)
      p(2125) = p(5)*p(438)
      p(2126) = p(9)*p(386)
      p(2127) = p(9)*p(387)
      p(2128) = p(9)*p(388)
      p(2129) = p(2)*p(323)
      p(2130) = p(9)*p(390)
      p(2131) = p(9)*p(391)
      p(2132) = p(9)*p(392)
      p(2133) = p(5)*p(327)
      p(2134) = p(9)*p(394)
      p(2135) = p(9)*p(395)
      p(2136) = p(9)*p(396)
      p(2137) = p(9)*p(397)
      p(2138) = p(2)*p(439)
      p(2139) = p(9)*p(399)
      p(2140) = p(9)*p(400)
      p(2141) = p(9)*p(401)
      p(2142) = p(5)*p(439)
      p(2143) = p(9)*p(403)
      p(2144) = p(9)*p(404)
      p(2145) = p(9)*p(405)
      p(2146) = p(9)*p(406)
      p(2147) = p(9)*p(407)
      p(2148) = p(9)*p(408)
      p(2149) = p(2)*p(334)
      p(2150) = p(9)*p(410)
      p(2151) = p(9)*p(411)
      p(2152) = p(9)*p(412)
      p(2153) = p(9)*p(413)
      p(2154) = p(5)*p(339)
      p(2155) = p(9)*p(415)
      p(2156) = p(9)*p(416)
      p(2157) = p(9)*p(417)
      p(2158) = p(9)*p(418)
      p(2159) = p(9)*p(419)
      p(2160) = p(2)*p(440)
      p(2161) = p(9)*p(421)
      p(2162) = p(9)*p(422)
      p(2163) = p(9)*p(423)
      p(2164) = p(9)*p(424)
      p(2165) = p(5)*p(440)
      p(2166) = p(9)*p(426)
      p(2167) = p(9)*p(427)
      p(2168) = p(9)*p(428)
      p(2169) = p(9)*p(429)
      p(2170) = p(9)*p(430)
      p(2171) = p(9)*p(431)
      p(2172) = p(9)*p(432)
      p(2173) = p(9)*p(298)
      p(2174) = p(2)*p(441)
      p(2175) = p(9)*p(300)
      p(2176) = p(2)*p(443)
      p(2177) = p(9)*p(302)
      p(2178) = p(9)*p(303)
      p(2179) = p(9)*p(304)
      p(2180) = p(2)*p(444)
      p(2181) = p(9)*p(306)
      p(2182) = p(9)*p(307)
      p(2183) = p(9)*p(308)
      p(2184) = p(9)*p(309)
      p(2185) = p(9)*p(310)
      p(2186) = p(5)*p(441)
      p(2187) = p(2)*p(445)
      p(2188) = p(5)*p(443)
      p(2189) = p(5)*p(444)
      p(2190) = p(9)*p(315)
      p(2191) = p(2)*p(446)
      p(2192) = p(9)*p(317)
      p(2193) = p(9)*p(318)
      p(2194) = p(5)*p(446)
      p(2195) = p(9)*p(320)
      p(2196) = p(9)*p(321)
      p(2197) = p(9)*p(322)
      p(2198) = p(2)*p(447)
      p(2199) = p(9)*p(324)
      p(2200) = p(9)*p(325)
      p(2201) = p(9)*p(326)
      p(2202) = p(5)*p(447)
      p(2203) = p(9)*p(328)
      p(2204) = p(9)*p(329)
      p(2205) = p(9)*p(330)
      p(2206) = p(9)*p(331)
      p(2207) = p(9)*p(332)
      p(2208) = p(9)*p(333)
      p(2209) = p(2)*p(448)
      p(2210) = p(9)*p(335)
      p(2211) = p(9)*p(336)
      p(2212) = p(9)*p(337)
      p(2213) = p(9)*p(338)
      p(2214) = p(5)*p(448)
      p(2215) = p(9)*p(340)
      p(2216) = p(9)*p(341)
      p(2217) = p(9)*p(342)
      p(2218) = p(9)*p(343)
      p(2219) = p(9)*p(344)
      p(2220) = p(9)*p(345)
      p(2221) = p(9)*p(346)
      p(2222) = p(10)*p(10)
      p(2223) = p(10)*p(67)
      p(2224) = p(2)*p(449)
      p(2225) = p(2)*p(348)
      p(2226) = p(2)*p(349)
      p(2227) = p(3)*p(449)
      p(2228) = p(2)*p(351)
      p(2229) = p(67)*p(69)
      p(2230) = p(2)*p(353)
      p(2231) = p(14)*p(14)
      p(2232) = p(1)*p(451)
      p(2233) = p(2)*p(451)
      p(2234) = p(14)*p(69)
      p(2235) = p(1)*p(355) - p(1498)
      p(2236) = p(1)*p(356) - p(1499)
      p(2237) = p(2)*p(357)
      p(2238) = p(3)*p(358) - p(1518)
      p(2239) = p(3)*p(359) - p(1522)
      p(2240) = p(1)*p(360) - p(1529)
      p(2241) = p(1)*p(361) - p(1529)
      p(2242) = p(2)*p(362)
      p(2243) = p(3)*p(363) - p(1547)
      p(2244) = p(19)*p(19) - p(492) - p(492)
      p(2245) = p(20)*p(20) - p(492) - p(492)
      p(2246) = p(3)*p(366) - p(1547)
      p(2247) = p(22)*p(22) - p(492) - p(492)
      p(2248) = p(4)*p(360) - p(1550) - p(1539) - p(1535)
      p(2249) = p(1)*p(452) - p(2248)
      p(2250) = p(2)*p(452)
      p(2251) = p(4)*p(363) - p(1553) - p(1542) - p(1538)
      p(2252) = p(19)*p(70) - p(1555)
      p(2253) = p(20)*p(70) - p(1554)
      p(2254) = p(3)*p(452) - p(2251)
      p(2255) = p(22)*p(70) - p(1543)
      p(2256) = p(5)*p(449)
      p(2257) = p(2)*p(369)
      p(2258) = p(5)*p(451)
      p(2259) = p(5)*p(452)
      p(2260) = p(5)*p(368)
      p(2261) = p(2)*p(373)
      p(2262) = p(5)*p(370)
      p(2263) = p(5)*p(371)
      p(2264) = p(5)*p(372)
      p(2265) = p(2)*p(453)
      p(2266) = p(5)*p(374)
      p(2267) = p(5)*p(375)
      p(2268) = p(6)*p(449)
      p(2269) = p(2)*p(377)
      p(2270) = p(6)*p(451)
      p(2271) = p(6)*p(452)
      p(2272) = p(5)*p(380)
      p(2273) = p(67)*p(72)
      p(2274) = p(2)*p(382)
      p(2275) = p(69)*p(72)
      p(2276) = p(70)*p(72)
      p(2277) = p(5)*p(385)
      p(2278) = p(32)*p(32)
      p(2279) = p(1)*p(454)
      p(2280) = p(2)*p(454)
      p(2281) = p(3)*p(454)
      p(2282) = p(4)*p(454)
      p(2283) = p(5)*p(454)
      p(2284) = p(32)*p(72)
      p(2285) = p(1)*p(387) - p(1647)
      p(2286) = p(1)*p(388) - p(1648)
      p(2287) = p(2)*p(389)
      p(2288) = p(7)*p(451)
      p(2289) = p(4)*p(391) - p(1677) - p(1675) - p(1669)
      p(2290) = p(7)*p(452) - p(2289)
      p(2291) = p(5)*p(393)
      p(2292) = p(6)*p(394) - p(1731)
      p(2293) = p(6)*p(395) - p(1739)
      p(2294) = p(1)*p(396) - p(1749)
      p(2295) = p(1)*p(397) - p(1749)
      p(2296) = p(2)*p(398)
      p(2297) = p(69)*p(73)
      p(2298) = p(4)*p(400) - p(1769) - p(1766) - p(1760) - p(1760)
      p(2299) = p(70)*p(73) - p(2298)
      p(2300) = p(5)*p(402)
      p(2301) = p(6)*p(403) - p(1807)
      p(2302) = p(41)*p(41) - p(800) - p(800)
      p(2303) = p(42)*p(42) - p(800) - p(800)
      p(2304) = p(6)*p(406) - p(1807)
      p(2305) = p(44)*p(44) - p(800) - p(800)
      p(2306) = p(7)*p(396) - p(1810) - p(1791) - p(1783)
      p(2307) = p(1)*p(455) - p(2306)
      p(2308) = p(2)*p(455)
      p(2309) = p(3)*p(455)
      p(2310) = p(7)*p(400) - p(1814) - p(1795) - p(1787)
      p(2311) = p(4)*p(455) - p(2310)
      p(2312) = p(5)*p(455)
      p(2313) = p(7)*p(403) - p(1817) - p(1798) - p(1790)
      p(2314) = p(41)*p(73) - p(1819)
      p(2315) = p(42)*p(73) - p(1818)
      p(2316) = p(6)*p(455) - p(2313)
      p(2317) = p(44)*p(73) - p(1799)
      p(2318) = p(8)*p(449)
      p(2319) = p(2)*p(409)
      p(2320) = p(3)*p(410) - p(1839)
      p(2321) = p(4)*p(411) - p(1850) - p(1849) - p(1836)
      p(2322) = p(3)*p(412) - p(1843)
      p(2323) = p(8)*p(452) - p(2321)
      p(2324) = p(5)*p(414)
      p(2325) = p(6)*p(415) - p(1928)
      p(2326) = p(7)*p(416) - p(1953) - p(1952) - p(1908)
      p(2327) = p(6)*p(417) - p(1937)
      p(2328) = p(8)*p(455) - p(2326)
      p(2329) = p(67)*p(74)
      p(2330) = p(2)*p(420)
      p(2331) = p(3)*p(421) - p(1992)
      p(2332) = p(4)*p(422) - p(1999) - p(1998) - p(1989) - p(1989)
      p(2333) = p(3)*p(423) - p(1992)
      p(2334) = p(70)*p(74) - p(2332)
      p(2335) = p(5)*p(425)
      p(2336) = p(6)*p(426) - p(2053)
      p(2337) = p(7)*p(427) - p(2069) - p(2068) - p(2026) - p(2026)
      p(2338) = p(54)*p(54) - p(1243) - p(1243)
      p(2339) = p(55)*p(55) - p(1243) - p(1243)
      p(2340) = p(6)*p(430) - p(2053)
      p(2341) = p(73)*p(74) - p(2337)
      p(2342) = p(58)*p(58) - p(1243) - p(1243)
      p(2343) = p(1)*p(456)
      p(2344) = p(2)*p(456)
      p(2345) = p(8)*p(421) - p(2076) - p(2038) - p(2029)
      p(2346) = p(8)*p(422) - p(2077) - p(2039) - p(2030)
      p(2347) = p(3)*p(456) - p(2345)
      p(2348) = p(4)*p(456) - p(2346)
      p(2349) = p(5)*p(456)
      p(2350) = p(8)*p(426) - p(2081) - p(2043) - p(2034)
      p(2351) = p(8)*p(427) - p(2082) - p(2044) - p(2035)
      p(2352) = p(54)*p(74) - p(2084)
      p(2353) = p(55)*p(74) - p(2083)
      p(2354) = p(6)*p(456) - p(2350)
      p(2355) = p(7)*p(456) - p(2351)
      p(2356) = p(58)*p(74) - p(2045)
      p(2357) = p(9)*p(449)
      p(2358) = p(2)*p(434)
      p(2359) = p(9)*p(451)
      p(2360) = p(9)*p(452)
      p(2361) = p(5)*p(437)
      p(2362) = p(9)*p(454)
      p(2363) = p(9)*p(455)
      p(2364) = p(9)*p(456)
      p(2365) = p(9)*p(433)
      p(2366) = p(2)*p(442)
      p(2367) = p(9)*p(435)
      p(2368) = p(9)*p(436)
      p(2369) = p(5)*p(445)
      p(2370) = p(9)*p(438)
      p(2371) = p(9)*p(439)
      p(2372) = p(9)*p(440)
      p(2373) = p(9)*p(441)
      p(2374) = p(2)*p(457)
      p(2375) = p(9)*p(443)
      p(2376) = p(9)*p(444)
      p(2377) = p(5)*p(457)
      p(2378) = p(9)*p(446)
      p(2379) = p(9)*p(447)
      p(2380) = p(9)*p(448)
      p(2381) = p(1)*p(449) - p(2223)
      p(2382) = p(2)*p(450)
      p(2383) = p(3)*p(451) - p(2234)
      p(2384) = p(4)*p(452) - p(2255) - p(2253) - p(2252)
      p(2385) = p(5)*p(453)
      p(2386) = p(6)*p(454) - p(2284)
      p(2387) = p(7)*p(455) - p(2317) - p(2315) - p(2314)
      p(2388) = p(8)*p(456) - p(2356) - p(2353) - p(2352)
      p(2389) = p(9)*p(457)

      return
      end subroutine evpoly
